@@ -26,13 +26,17 @@ mod write;
 pub(crate) mod chain;
 pub(crate) mod manager;
 
-pub mod capture_bytes;
+pub mod capture;
 pub mod compress;
 pub mod concatenate_bytes;
 pub mod debug;
+pub mod drop;
+pub mod firewall;
 pub mod load_balancer;
 pub mod local_rate_limit;
+pub mod r#match;
 pub mod metadata;
+pub mod pass;
 pub mod token_router;
 
 /// Prelude containing all types and traits required to implement [`Filter`] and
