@@ -14,12 +14,13 @@
  * limitations under the License.
  */
 
-use prometheus::{Error as PrometheusError, Histogram, HistogramOpts, Registry};
+use std::sync::Arc;
+
+use prometheus::{exponential_buckets, Error as PrometheusError, Histogram, Registry};
 
 use crate::config::{Filter as FilterConfig, ValidationError};
 use crate::filters::{prelude::*, FilterRegistry};
-use crate::metrics::CollectorExt;
-use std::sync::Arc;
+use crate::metrics::{histogram_opts, CollectorExt};
 
 const FILTER_LABEL: &str = "filter";
 
@@ -52,16 +53,35 @@ impl From<PrometheusError> for Error {
     }
 }
 
+/// Start the histogram bucket at an eighth of a millisecond, as we bucketed the full filter
+/// chain processing starting at a quarter of a millisecond, so we we will want finer granularity
+/// here.
+const BUCKET_START: f64 = 0.000125;
+
+const BUCKET_FACTOR: f64 = 2.5;
+
+/// At an exponential factor of 2.5 (BUCKET_FACTOR), 11 iterations gets us to just over half a
+/// second. Any processing that occurs over half a second is far too long, so we end
+/// the bucketing there as we don't care about granularity past this value.
+const BUCKET_COUNT: usize = 11;
+
 impl FilterChain {
     pub fn new(filters: Vec<(String, FilterInstance)>, registry: &Registry) -> Result<Self, Error> {
+        let subsystem = "filter";
+
         Ok(Self {
             filter_read_duration_seconds: filters
                 .iter()
                 .map(|(name, _)| {
                     Histogram::with_opts(
-                        HistogramOpts::new(
-                            "filter_read_duration_seconds",
+                        histogram_opts(
+                            "read_duration_seconds",
+                            subsystem,
                             "Seconds taken to execute a given filter's `read`.",
+                            Some(
+                                exponential_buckets(BUCKET_START, BUCKET_FACTOR, BUCKET_COUNT)
+                                    .unwrap(),
+                            ),
                         )
                         .const_label(FILTER_LABEL, name),
                     )
@@ -72,9 +92,11 @@ impl FilterChain {
                 .iter()
                 .map(|(name, _)| {
                     Histogram::with_opts(
-                        HistogramOpts::new(
-                            "filter_write_duration_seconds",
+                        histogram_opts(
+                            "write_duration_seconds",
+                            subsystem,
                             "Seconds taken to execute a given filter's `write`.",
+                            Some(exponential_buckets(0.000125, 2.5, 11).unwrap()),
                         )
                         .const_label(FILTER_LABEL, name),
                     )
@@ -97,8 +119,12 @@ impl FilterChain {
         for filter_config in filter_configs {
             match filter_registry.get(
                 &filter_config.name,
-                CreateFilterArgs::fixed(metrics_registry.clone(), filter_config.config.as_ref())
-                    .with_metrics_registry(metrics_registry.clone()),
+                CreateFilterArgs::fixed(
+                    filter_registry.clone(),
+                    metrics_registry.clone(),
+                    filter_config.config,
+                )
+                .with_metrics_registry(metrics_registry.clone()),
             ) {
                 Ok(filter) => filters.push((filter_config.name, filter)),
                 Err(err) => {
@@ -128,7 +154,7 @@ impl Filter for FilterChain {
             .zip(self.filter_read_duration_seconds.iter())
             .try_fold(ctx, |ctx, ((_, instance), histogram)| {
                 Some(ReadContext::with_response(
-                    ctx.from,
+                    ctx.source.clone(),
                     histogram.observe_closure_duration(|| instance.filter.read(ctx))?,
                 ))
             })
@@ -143,8 +169,8 @@ impl Filter for FilterChain {
             .try_fold(ctx, |ctx, ((_, instance), histogram)| {
                 Some(WriteContext::with_response(
                     ctx.endpoint,
-                    ctx.from,
-                    ctx.to,
+                    ctx.source.clone(),
+                    ctx.dest.clone(),
                     histogram.observe_closure_duration(|| instance.filter.write(ctx))?,
                 ))
             })
@@ -160,15 +186,14 @@ mod tests {
         config,
         endpoint::{Endpoint, Endpoints, UpstreamEndpoints},
         filters::{debug, FilterRegistry, FilterSet},
-        test_utils::{logger, new_test_chain, TestFilterFactory},
+        test_utils::{new_test_chain, TestFilterFactory},
     };
 
     use super::*;
 
     #[test]
     fn from_config() {
-        let log = logger();
-        let provider = debug::factory(&log);
+        let provider = debug::factory();
 
         // everything is fine
         let filter_configs = vec![config::Filter {
@@ -176,7 +201,7 @@ mod tests {
             config: Default::default(),
         }];
 
-        let registry = FilterRegistry::new(FilterSet::default(&log));
+        let registry = FilterRegistry::new(FilterSet::default());
         let chain =
             FilterChain::try_create(filter_configs, &registry, &Registry::default()).unwrap();
         assert_eq!(1, chain.filters.len());
@@ -227,14 +252,14 @@ mod tests {
         assert_eq!(
             "receive",
             response.metadata[&"downstream".to_string()]
-                .downcast_ref::<String>()
+                .as_string()
                 .unwrap()
         );
 
         let response = chain
             .write(WriteContext::new(
                 &endpoints_fixture[0],
-                endpoints_fixture[0].address,
+                endpoints_fixture[0].address.clone(),
                 "127.0.0.1:70".parse().unwrap(),
                 b"hello".to_vec(),
             ))
@@ -242,8 +267,8 @@ mod tests {
 
         assert_eq!(
             "receive",
-            response.metadata["upstream"]
-                .downcast_ref::<String>()
+            response.metadata[&"upstream".to_string()]
+                .as_string()
                 .unwrap()
         );
         assert_eq!(
@@ -292,14 +317,14 @@ mod tests {
         assert_eq!(
             "receive:receive",
             response.metadata[&"downstream".to_string()]
-                .downcast_ref::<String>()
+                .as_string()
                 .unwrap()
         );
 
         let response = chain
             .write(WriteContext::new(
                 &endpoints_fixture[0],
-                endpoints_fixture[0].address,
+                endpoints_fixture[0].address.clone(),
                 "127.0.0.1:70".parse().unwrap(),
                 b"hello".to_vec(),
             ))
@@ -310,8 +335,8 @@ mod tests {
         );
         assert_eq!(
             "receive:receive",
-            response.metadata["upstream"]
-                .downcast_ref::<String>()
+            response.metadata[&"upstream".to_string()]
+                .as_string()
                 .unwrap()
         );
     }
