@@ -18,28 +18,26 @@ mod compressor;
 mod config;
 mod metrics;
 
-crate::include_proto!("quilkin.extensions.filters.compress.v1alpha1");
-
-use slog::{o, warn, Logger};
+crate::include_proto!("quilkin.filters.compress.v1alpha1");
 
 use crate::{config::LOG_SAMPLING_RATE, filters::prelude::*};
+use tracing::warn;
 
-use self::quilkin::extensions::filters::compress::v1alpha1::Compress as ProtoConfig;
+use self::quilkin::filters::compress::v1alpha1::Compress as ProtoConfig;
 use compressor::Compressor;
 use metrics::Metrics;
 
 pub use config::{Action, Config, Mode};
 
-pub const NAME: &str = "quilkin.extensions.filters.compress.v1alpha1.Compress";
+pub const NAME: &str = "quilkin.filters.compress.v1alpha1.Compress";
 
 /// Returns a factory for creating compression filters.
-pub fn factory(base: &Logger) -> DynFilterFactory {
-    Box::from(CompressFactory::new(base))
+pub fn factory() -> DynFilterFactory {
+    Box::from(CompressFactory::new())
 }
 
 /// Filter for compressing and decompressing packet data
 struct Compress {
-    log: Logger,
     metrics: Metrics,
     compression_mode: Mode,
     on_read: Action,
@@ -48,9 +46,8 @@ struct Compress {
 }
 
 impl Compress {
-    fn new(base: &Logger, config: Config, metrics: Metrics) -> Self {
+    fn new(config: Config, metrics: Metrics) -> Self {
         Self {
-            log: base.new(o!("source" => "extensions::Compress")),
             metrics,
             compressor: config.mode.as_compressor(),
             compression_mode: config.mode,
@@ -62,9 +59,8 @@ impl Compress {
     /// Track a failed attempt at compression
     fn failed_compression<T>(&self, err: &dyn std::error::Error) -> Option<T> {
         if self.metrics.packets_dropped_compress.get() % LOG_SAMPLING_RATE == 0 {
-            warn!(self.log, "Packets are being dropped as they could not be compressed";
-                            "mode" => #?self.compression_mode, "error" => %err,
-                            "count" => self.metrics.packets_dropped_compress.get());
+            warn!(mode = ?self.compression_mode, error = %err, count = self.metrics.packets_dropped_compress.get(),
+            "Packets are being dropped as they could not be compressed");
         }
         self.metrics.packets_dropped_compress.inc();
         None
@@ -73,9 +69,8 @@ impl Compress {
     /// Track a failed attempt at decompression
     fn failed_decompression<T>(&self, err: &dyn std::error::Error) -> Option<T> {
         if self.metrics.packets_dropped_decompress.get() % LOG_SAMPLING_RATE == 0 {
-            warn!(self.log, "Packets are being dropped as they could not be decompressed";
-                            "mode" => #?self.compression_mode, "error" => %err,
-                            "count" => self.metrics.packets_dropped_decompress.get());
+            warn!(mode = ?self.compression_mode, error = %err, count = ?self.metrics.packets_dropped_decompress.get(),
+            "Packets are being dropped as they could not be decompressed");
         }
         self.metrics.packets_dropped_decompress.inc();
         None
@@ -83,6 +78,7 @@ impl Compress {
 }
 
 impl Filter for Compress {
+    #[cfg_attr(feature = "instrument", tracing::instrument(skip(self, ctx)))]
     fn read(&self, mut ctx: ReadContext) -> Option<ReadResponse> {
         let original_size = ctx.contents.len();
 
@@ -115,6 +111,7 @@ impl Filter for Compress {
         }
     }
 
+    #[cfg_attr(feature = "instrument", tracing::instrument(skip(self, ctx)))]
     fn write(&self, mut ctx: WriteContext) -> Option<WriteResponse> {
         let original_size = ctx.contents.len();
         match self.on_write {
@@ -148,13 +145,11 @@ impl Filter for Compress {
     }
 }
 
-struct CompressFactory {
-    log: Logger,
-}
+struct CompressFactory {}
 
 impl CompressFactory {
-    pub fn new(base: &Logger) -> Self {
-        CompressFactory { log: base.clone() }
+    pub fn new() -> Self {
+        CompressFactory {}
     }
 }
 
@@ -163,11 +158,15 @@ impl FilterFactory for CompressFactory {
         NAME
     }
 
+    fn config_schema(&self) -> schemars::schema::RootSchema {
+        schemars::schema_for!(Config)
+    }
+
     fn create_filter(&self, args: CreateFilterArgs) -> Result<FilterInstance, Error> {
         let (config_json, config) = self
             .require_config(args.config)?
             .deserialize::<Config, ProtoConfig>(self.name())?;
-        let filter = Compress::new(&self.log, config, Metrics::new(&args.metrics_registry)?);
+        let filter = Compress::new(config, Metrics::new(&args.metrics_registry)?);
         Ok(FilterInstance::new(
             config_json,
             Box::new(filter) as Box<dyn Filter>,
@@ -181,15 +180,15 @@ mod tests {
 
     use prometheus::Registry;
     use serde_yaml::{Mapping, Value};
+    use tracing_test::traced_test;
 
     use crate::endpoint::{Endpoint, Endpoints, UpstreamEndpoints};
     use crate::filters::{
         compress::{compressor::Snappy, Compressor},
-        CreateFilterArgs, Filter, FilterFactory, ReadContext, WriteContext,
+        CreateFilterArgs, Filter, FilterFactory, FilterRegistry, ReadContext, WriteContext,
     };
-    use crate::test_utils::logger;
 
-    use super::quilkin::extensions::filters::compress::v1alpha1::{
+    use super::quilkin::filters::compress::v1alpha1::{
         compress::{Action as ProtoAction, ActionValue, Mode as ProtoMode, ModeValue},
         Compress as ProtoConfig,
     };
@@ -286,8 +285,7 @@ mod tests {
 
     #[test]
     fn default_mode_factory() {
-        let log = logger();
-        let factory = CompressFactory::new(&log);
+        let factory = CompressFactory::new();
         let mut map = Mapping::new();
         map.insert(
             Value::String("on_read".into()),
@@ -299,8 +297,9 @@ mod tests {
         );
         let filter = factory
             .create_filter(CreateFilterArgs::fixed(
+                FilterRegistry::default(),
                 Registry::default(),
-                Some(&Value::Mapping(map)),
+                Some(Value::Mapping(map)),
             ))
             .expect("should create a filter")
             .filter;
@@ -309,8 +308,7 @@ mod tests {
 
     #[test]
     fn config_factory() {
-        let log = logger();
-        let factory = CompressFactory::new(&log);
+        let factory = CompressFactory::new();
         let mut map = Mapping::new();
         map.insert(Value::String("mode".into()), Value::String("SNAPPY".into()));
         map.insert(
@@ -322,7 +320,8 @@ mod tests {
             Value::String("COMPRESS".into()),
         );
         let config = Value::Mapping(map);
-        let args = CreateFilterArgs::fixed(Registry::default(), Some(&config));
+        let args =
+            CreateFilterArgs::fixed(FilterRegistry::default(), Registry::default(), Some(config));
 
         let filter = factory
             .create_filter(args)
@@ -333,9 +332,7 @@ mod tests {
 
     #[test]
     fn upstream() {
-        let log = logger();
         let compress = Compress::new(
-            &log,
             Config {
                 mode: Default::default(),
                 on_read: Action::Compress,
@@ -399,9 +396,7 @@ mod tests {
 
     #[test]
     fn downstream() {
-        let log = logger();
         let compress = Compress::new(
-            &log,
             Config {
                 mode: Default::default(),
                 on_read: Action::Decompress,
@@ -426,11 +421,10 @@ mod tests {
         assert_eq!(0, compress.metrics.packets_dropped_compress.get());
     }
 
+    #[traced_test]
     #[test]
     fn failed_decompress() {
-        let log = logger();
         let compression = Compress::new(
-            &log,
             Config {
                 mode: Default::default(),
                 on_read: Action::Compress,
@@ -451,7 +445,6 @@ mod tests {
         assert_eq!(0, compression.metrics.packets_dropped_compress.get());
 
         let compression = Compress::new(
-            &log,
             Config {
                 mode: Default::default(),
                 on_read: Action::Decompress,
@@ -468,6 +461,11 @@ mod tests {
             b"hello".to_vec(),
         ));
 
+        assert!(logs_contain(
+            "Packets are being dropped as they could not be decompressed"
+        ));
+        assert!(logs_contain("quilkin::filters::compress")); // the given name to the the logger by tracing
+
         assert!(read_response.is_none());
         assert_eq!(1, compression.metrics.packets_dropped_decompress.get());
         assert_eq!(0, compression.metrics.packets_dropped_compress.get());
@@ -477,9 +475,7 @@ mod tests {
 
     #[test]
     fn do_nothing() {
-        let log = logger();
         let compression = Compress::new(
-            &log,
             Config {
                 mode: Default::default(),
                 on_read: Action::default(),
