@@ -14,14 +14,12 @@
  * limitations under the License.
  */
 
-use std::{any::Any, collections::HashMap, net::SocketAddr, sync::Arc};
-
-use crate::endpoint::UpstreamEndpoints;
 #[cfg(doc)]
 use crate::filters::Filter;
-
-/// Shared state between [`Filter`]s during processing for a single packet.
-type DynamicMetadata = HashMap<Arc<String>, Box<dyn Any + Send>>;
+use crate::{
+    endpoint::{EndpointAddress, UpstreamEndpoints},
+    metadata::DynamicMetadata,
+};
 
 /// The input arguments to [`Filter::read`].
 #[non_exhaustive]
@@ -29,7 +27,7 @@ pub struct ReadContext {
     /// The upstream endpoints that the packet will be forwarded to.
     pub endpoints: UpstreamEndpoints,
     /// The source of the received packet.
-    pub from: SocketAddr,
+    pub source: EndpointAddress,
     /// Contents of the received packet.
     pub contents: Vec<u8>,
     /// Arbitrary values that can be passed from one filter to another.
@@ -38,20 +36,20 @@ pub struct ReadContext {
 
 impl ReadContext {
     /// Creates a new [`ReadContext`].
-    pub fn new(endpoints: UpstreamEndpoints, from: SocketAddr, contents: Vec<u8>) -> Self {
+    pub fn new(endpoints: UpstreamEndpoints, source: EndpointAddress, contents: Vec<u8>) -> Self {
         Self {
             endpoints,
-            from,
+            source,
             contents,
-            metadata: HashMap::new(),
+            metadata: DynamicMetadata::new(),
         }
     }
 
     /// Creates a new [`ReadContext`] from a given [`ReadResponse`].
-    pub fn with_response(from: SocketAddr, response: ReadResponse) -> Self {
+    pub fn with_response(source: EndpointAddress, response: ReadResponse) -> Self {
         Self {
             endpoints: response.endpoints,
-            from,
+            source,
             contents: response.contents,
             metadata: response.metadata,
         }
@@ -78,6 +76,7 @@ impl From<ReadContext> for ReadResponse {
 ///       Some(ctx.into())
 ///   }
 /// ```
+#[derive(Debug)]
 #[non_exhaustive]
 pub struct ReadResponse {
     /// The upstream endpoints that the packet should be forwarded to.
