@@ -55,12 +55,12 @@ impl FilterRegistry {
 
 #[cfg(test)]
 mod tests {
-    use std::net::{IpAddr, Ipv4Addr, SocketAddr};
+    use std::net::Ipv4Addr;
 
-    use crate::test_utils::{logger, new_registry};
+    use crate::test_utils::new_registry;
 
     use super::*;
-    use crate::endpoint::{Endpoint, Endpoints};
+    use crate::endpoint::{Endpoint, EndpointAddress, Endpoints};
     use crate::filters::{Filter, ReadContext, ReadResponse, WriteContext, WriteResponse};
     use prometheus::Registry;
 
@@ -78,11 +78,11 @@ mod tests {
 
     #[test]
     fn insert_and_get() {
-        let reg = new_registry(&logger());
+        let reg = new_registry();
 
         match reg.get(
             &String::from("not.found"),
-            CreateFilterArgs::fixed(Registry::default(), None),
+            CreateFilterArgs::fixed(reg.clone(), Registry::default(), None),
         ) {
             Ok(_) => unreachable!("should not be filter"),
             Err(err) => assert_eq!(Error::NotFound("not.found".to_string()), err),
@@ -91,32 +91,30 @@ mod tests {
         assert!(reg
             .get(
                 &String::from("TestFilter"),
-                CreateFilterArgs::fixed(Registry::default(), None)
+                CreateFilterArgs::fixed(reg.clone(), Registry::default(), None)
             )
             .is_ok());
 
         let filter = reg
             .get(
                 &String::from("TestFilter"),
-                CreateFilterArgs::fixed(Registry::default(), None),
+                CreateFilterArgs::fixed(reg.clone(), Registry::default(), None),
             )
             .unwrap()
             .filter;
 
-        let addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
-        let endpoint = Endpoint::new(addr);
+        let addr: EndpointAddress = (Ipv4Addr::LOCALHOST, 8080).into();
+        let endpoint = Endpoint::new(addr.clone());
 
         assert!(filter
             .read(ReadContext::new(
-                Endpoints::new(vec![Endpoint::new("127.0.0.1:8080".parse().unwrap(),)])
-                    .unwrap()
-                    .into(),
-                addr,
+                Endpoints::new(vec![endpoint.clone()]).unwrap().into(),
+                addr.clone(),
                 vec![]
             ))
             .is_some());
         assert!(filter
-            .write(WriteContext::new(&endpoint, addr, addr, vec![],))
+            .write(WriteContext::new(&endpoint, addr.clone(), addr, vec![],))
             .is_some());
     }
 }
