@@ -16,8 +16,6 @@
 
 use std::iter::FromIterator;
 
-use slog::Logger;
-
 use crate::filters::{self, DynFilterFactory};
 
 #[cfg(doc)]
@@ -39,11 +37,11 @@ impl FilterSet {
     /// - [`local_rate_limit`][filters::local_rate_limit]
     /// - [`concatenate_bytes`][filters::concatenate_bytes]
     /// - [`load_balancer`][filters::load_balancer]
-    /// - [`capture_bytes`][filters::capture_bytes]
+    /// - [`capture`][filters::capture]
     /// - [`token_router`][filters::token_router]
     /// - [`compress`][filters::compress]
-    pub fn default(base: &Logger) -> Self {
-        Self::default_with(base, Option::into_iter(None))
+    pub fn default() -> Self {
+        Self::default_with(Option::into_iter(None))
     }
 
     /// Returns a `FilterSet` with the filters provided through `filters` in
@@ -51,20 +49,22 @@ impl FilterSet {
     /// will override any defaults with a matching name.
     ///
     /// See [`FilterSet::default`] for a list of the current defaults.
-    pub fn default_with(
-        base: &Logger,
-        filters: impl IntoIterator<Item = DynFilterFactory>,
-    ) -> Self {
+    pub fn default_with(filters: impl IntoIterator<Item = DynFilterFactory>) -> Self {
         Self::with(
-            std::array::IntoIter::new([
-                filters::debug::factory(base),
-                filters::local_rate_limit::factory(),
+            [
+                filters::capture::factory(),
+                filters::compress::factory(),
                 filters::concatenate_bytes::factory(),
+                filters::debug::factory(),
+                filters::drop::factory(),
+                filters::firewall::factory(),
                 filters::load_balancer::factory(),
-                filters::capture_bytes::factory(base),
-                filters::token_router::factory(base),
-                filters::compress::factory(base),
-            ])
+                filters::local_rate_limit::factory(),
+                filters::r#match::factory(),
+                filters::pass::factory(),
+                filters::token_router::factory(),
+            ]
+            .into_iter()
             .chain(filters),
         )
     }
@@ -74,6 +74,19 @@ impl FilterSet {
     pub fn with(filters: impl IntoIterator<Item = DynFilterFactory>) -> Self {
         Self::from_iter(filters)
     }
+
+    /// Returns a [`DynFilterFactory`] if one matches `id`, otherwise returns
+    /// `None`.
+    pub fn get(&self, id: &str) -> Option<&DynFilterFactory> {
+        self.0.get(id)
+    }
+
+    /// Returns a by reference iterator over the set of filters.
+    pub fn iter(&self) -> Iter {
+        Iter {
+            inner: self.0.iter(),
+        }
+    }
 }
 
 impl<I: Iterator<Item = DynFilterFactory>> From<I> for FilterSet {
@@ -117,3 +130,16 @@ impl Iterator for IntoIter {
         self.inner.next().map(|(_, v)| v)
     }
 }
+
+/// Iterator over a set of [`DynFilterFactory`]s.
+pub struct Iter<'r> {
+    inner: std::collections::hash_map::Iter<'r, &'static str, DynFilterFactory>,
+}
+
+impl<'r> Iterator for Iter<'r> {
+    type Item = &'r DynFilterFactory;
+
+    fn next(&mut self) -> Option<Self::Item> {
+        self.inner.next().map(|(_, v)| v)
+    }
+}
