@@ -14,9 +14,12 @@
  * limitations under the License.
  */
 
-use std::{any::Any, collections::HashMap, net::SocketAddr};
+use std::collections::HashMap;
 
-use crate::endpoint::Endpoint;
+use crate::{
+    endpoint::{Endpoint, EndpointAddress},
+    metadata::DynamicMetadata,
+};
 
 #[cfg(doc)]
 use crate::filters::Filter;
@@ -27,13 +30,13 @@ pub struct WriteContext<'a> {
     /// The upstream endpoint that we're expecting packets from.
     pub endpoint: &'a Endpoint,
     /// The source of the received packet.
-    pub from: SocketAddr,
+    pub source: EndpointAddress,
     /// The destination of the received packet.
-    pub to: SocketAddr,
+    pub dest: EndpointAddress,
     /// Contents of the received packet.
     pub contents: Vec<u8>,
     /// Arbitrary values that can be passed from one filter to another
-    pub metadata: HashMap<String, Box<dyn Any + Send>>,
+    pub metadata: DynamicMetadata,
 }
 
 /// The output of [`Filter::write`].
@@ -51,21 +54,21 @@ pub struct WriteResponse {
     /// Contents of the packet to be sent back to the original sender.
     pub contents: Vec<u8>,
     /// Arbitrary values that can be passed from one filter to another.
-    pub metadata: HashMap<String, Box<dyn Any + Send>>,
+    pub metadata: DynamicMetadata,
 }
 
 impl WriteContext<'_> {
     /// Creates a new [`WriteContext`]
     pub fn new(
         endpoint: &Endpoint,
-        from: SocketAddr,
-        to: SocketAddr,
+        source: EndpointAddress,
+        dest: EndpointAddress,
         contents: Vec<u8>,
     ) -> WriteContext {
         WriteContext {
             endpoint,
-            from,
-            to,
+            source,
+            dest,
             contents,
             metadata: HashMap::new(),
         }
@@ -74,14 +77,14 @@ impl WriteContext<'_> {
     /// Creates a new [`WriteContext`] from a given [`WriteResponse`].
     pub fn with_response(
         endpoint: &Endpoint,
-        from: SocketAddr,
-        to: SocketAddr,
+        source: EndpointAddress,
+        dest: EndpointAddress,
         response: WriteResponse,
     ) -> WriteContext {
         WriteContext {
             endpoint,
-            from,
-            to,
+            source,
+            dest,
             contents: response.contents,
             metadata: response.metadata,
         }
