@@ -20,6 +20,7 @@ pub(crate) mod metrics;
 pub(crate) mod prost;
 mod proxy;
 mod runner;
+pub(crate) mod ttl_map;
 pub(crate) mod utils;
 pub(crate) mod xds;
 
@@ -30,13 +31,13 @@ pub mod filters;
 #[doc(hidden)]
 pub mod test_utils;
 
-pub type Result<T, E = runner::Error> = std::result::Result<T, E>;
+pub type Result<T, E = eyre::Error> = std::result::Result<T, E>;
 
 #[doc(inline)]
 pub use self::{
     config::Config,
-    proxy::{logger, Builder, PendingValidation, Server, Validated},
-    runner::{run, run_with_config},
+    proxy::{Builder, PendingValidation, Server, Validated},
+    runner::run,
 };
 
 pub use quilkin_macros::include_proto;
@@ -49,7 +50,8 @@ mod external_doc_tests {
     #![doc = include_str!("../docs/src/filters/local_rate_limit.md")]
     #![doc = include_str!("../docs/src/filters/debug.md")]
     #![doc = include_str!("../docs/src/filters/concatenate_bytes.md")]
-    #![doc = include_str!("../docs/src/filters/capture_bytes.md")]
+    #![doc = include_str!("../docs/src/filters/capture.md")]
     #![doc = include_str!("../docs/src/filters/token_router.md")]
     #![doc = include_str!("../docs/src/filters/compress.md")]
+    #![doc = include_str!("../docs/src/filters/firewall.md")]
 }
