@@ -20,7 +20,6 @@ use std::sync::Arc;
 
 use hyper::service::{make_service_fn, service_fn};
 use hyper::{Body, Method, Request, Response, Server as HyperServer, StatusCode};
-use slog::{error, info, o, Logger};
 use tokio::sync::watch;
 
 use crate::cluster::cluster_manager::SharedClusterManager;
@@ -28,7 +27,6 @@ use crate::filters::manager::SharedFilterManager;
 use crate::proxy::{config_dump, Health, Metrics};
 
 pub struct Admin {
-    log: Logger,
     /// The address that the Admin server starts on
     addr: SocketAddr,
     metrics: Arc<Metrics>,
@@ -44,9 +42,8 @@ struct HandleRequestArgs {
 }
 
 impl Admin {
-    pub fn new(base: &Logger, addr: SocketAddr, metrics: Arc<Metrics>, heath: Health) -> Self {
+    pub fn new(addr: SocketAddr, metrics: Arc<Metrics>, heath: Health) -> Self {
         Admin {
-            log: base.new(o!("source" => "proxy::Admin")),
             addr,
             metrics,
             health: Arc::new(heath),
@@ -59,7 +56,7 @@ impl Admin {
         filter_manager: SharedFilterManager,
         mut shutdown_rx: watch::Receiver<()>,
     ) {
-        info!(self.log, "Starting admin endpoint"; "address" => self.addr.to_string());
+        tracing::info!(address = %self.addr, "Starting admin endpoint");
 
         let args = HandleRequestArgs {
             metrics: self.metrics.clone(),
@@ -84,10 +81,9 @@ impl Admin {
                 shutdown_rx.changed().await.ok();
             });
 
-        let log = self.log.clone();
         tokio::spawn(async move {
-            if let Err(err) = server.await {
-                error!(log, "Admin server exited with an error"; "error" => %err);
+            if let Err(error) = server.await {
+                tracing::error!(%error, "Admin server exited with an error");
             }
         });
     }
