@@ -14,11 +14,10 @@
  * limitations under the License.
  */
 
-use std::net::{Ipv4Addr, SocketAddr, SocketAddrV4};
-use std::result::Result as StdResult;
+use std::net::{Ipv4Addr, SocketAddrV4};
 use std::sync::Arc;
 
-use slog::{debug, error, info, trace, warn, Logger};
+use prometheus::HistogramTimer;
 use tokio::net::UdpSocket;
 use tokio::sync::{mpsc, watch};
 use tokio::task::JoinHandle;
@@ -27,29 +26,30 @@ use tokio::time::Duration;
 use metrics::Metrics as ProxyMetrics;
 use resource_manager::{DynamicResourceManagers, StaticResourceManagers};
 
-use crate::cluster::cluster_manager::SharedClusterManager;
-use crate::endpoint::Endpoint;
-use crate::filters::{manager::SharedFilterManager, Filter, FilterRegistry, ReadContext};
-use crate::proxy::builder::{ValidatedConfig, ValidatedSource};
-use crate::proxy::server::error::Error;
-use crate::proxy::sessions::metrics::Metrics as SessionMetrics;
-use crate::proxy::sessions::session_manager::SessionManager;
-use crate::proxy::sessions::{Packet, Session, SessionKey, SESSION_TIMEOUT_SECONDS};
-use crate::proxy::Admin;
-use crate::utils::debug;
+use crate::{
+    cluster::cluster_manager::SharedClusterManager,
+    endpoint::{Endpoint, EndpointAddress},
+    filters::{manager::SharedFilterManager, Filter, FilterRegistry, ReadContext},
+    proxy::{
+        builder::{ValidatedConfig, ValidatedSource},
+        sessions::{
+            metrics::Metrics as SessionMetrics, session_manager::SessionManager, Session,
+            SessionArgs, SessionKey, UpstreamPacket, SESSION_TIMEOUT_SECONDS,
+        },
+        Admin,
+    },
+    utils::debug,
+    Result,
+};
 
 use super::metrics::Metrics;
 
-pub mod error;
 pub(super) mod metrics;
 mod resource_manager;
 
-type Result<T> = std::result::Result<T, Error>;
-
 /// Server is the UDP server main implementation
 pub struct Server {
     // We use pub(super) to limit instantiation only to the Builder.
-    pub(super) log: Logger,
     pub(super) config: Arc<ValidatedConfig>,
     // Admin may be turned off, primarily for testing.
     pub(super) admin: Option<Admin>,
@@ -66,17 +66,25 @@ struct RunRecvFromArgs {
     socket: Arc<UdpSocket>,
     session_manager: SessionManager,
     session_ttl: Duration,
-    send_packets: mpsc::Sender<Packet>,
+    send_packets: mpsc::Sender<UpstreamPacket>,
     shutdown_rx: watch::Receiver<()>,
 }
 
+/// Packet received from local port
+#[derive(Debug)]
+struct DownstreamPacket {
+    source: EndpointAddress,
+    contents: Vec<u8>,
+    timer: HistogramTimer,
+}
+
 /// Represents the required arguments to run a worker task that
 /// processes packets received downstream.
 struct DownstreamReceiveWorkerConfig {
     /// ID of the worker.
     worker_id: usize,
     /// Channel from which the worker picks up the downstream packets.
-    packet_rx: mpsc::Receiver<(SocketAddr, Vec<u8>)>,
+    packet_rx: mpsc::Receiver<DownstreamPacket>,
     /// Configuration required to process a received downstream packet.
     receive_config: ProcessDownstreamReceiveConfig,
     /// The worker task exits when a value is received from this shutdown channel.
@@ -86,25 +94,28 @@ struct DownstreamReceiveWorkerConfig {
 /// Contains arguments to process a received downstream packet, through the
 /// filter chain and session pipeline.
 struct ProcessDownstreamReceiveConfig {
-    log: Logger,
     proxy_metrics: ProxyMetrics,
     session_metrics: SessionMetrics,
     cluster_manager: SharedClusterManager,
     filter_manager: SharedFilterManager,
     session_manager: SessionManager,
     session_ttl: Duration,
-    send_packets: mpsc::Sender<Packet>,
+    send_packets: mpsc::Sender<UpstreamPacket>,
 }
 
 impl Server {
     /// start the async processing of incoming UDP packets. Will block until an
     /// event is sent through the stop Receiver.
     pub async fn run(self, mut shutdown_rx: watch::Receiver<()>) -> Result<()> {
-        self.log_config();
+        tracing::info!(
+            port = self.config.proxy.port,
+            proxy_id = &*self.config.proxy.id,
+            "Starting"
+        );
 
         let socket = Arc::new(Server::bind(self.config.proxy.port).await?);
-        let session_manager = SessionManager::new(self.log.clone(), shutdown_rx.clone());
-        let (send_packets, receive_packets) = mpsc::channel::<Packet>(1024);
+        let session_manager = SessionManager::new(shutdown_rx.clone());
+        let (send_packets, receive_packets) = mpsc::channel::<UpstreamPacket>(1024);
 
         let session_ttl = Duration::from_secs(SESSION_TIMEOUT_SECONDS);
 
@@ -130,11 +141,13 @@ impl Server {
             shutdown_rx: shutdown_rx.clone(),
         });
 
+        tracing::info!("Quilkin is ready.");
+
         tokio::select! {
             join_result = recv_loop => {
                 join_result
-                    .map_err(|join_err| Error::RecvLoop(format!("{}", join_err)))
-                    .and_then(|inner| inner.map_err(Error::RecvLoop))
+                    .map_err(|error| eyre::eyre!(error))
+                    .and_then(|inner| inner)
             }
             _ = shutdown_rx.changed() => {
                 Ok(())
@@ -156,12 +169,13 @@ impl Server {
                     endpoints.clone(),
                     filter_chain.clone(),
                 )
-                .map_err(|err| Error::Initialize(format!("{}", err)))?;
+                .map_err(|err| {
+                    eyre::eyre!(err).wrap_err("Failed to initialise static resource manager.")
+                })?;
                 Ok((manager.cluster_manager, manager.filter_manager))
             }
             ValidatedSource::Dynamic { management_servers } => {
                 let manager = DynamicResourceManagers::new(
-                    self.log.clone(),
                     self.config.proxy.id.clone(),
                     self.metrics.registry.clone(),
                     self.filter_registry.clone(),
@@ -169,19 +183,20 @@ impl Server {
                     shutdown_rx,
                 )
                 .await
-                .map_err(|err| Error::Initialize(format!("{}", err)))?;
+                .map_err(|err| {
+                    eyre::eyre!(err).wrap_err("Failed to initialise xDS management servers.")
+                })?;
 
                 let execution_result_rx = manager.execution_result_rx;
                 // Spawn a task to check for an error if the XDS client
                 // terminates and forward the error upstream.
-                let log = self.log.clone();
                 tokio::spawn(async move {
-                    if let Err(err) = execution_result_rx.await {
+                    if let Err(error) = execution_result_rx.await {
                         // TODO: For now only log the error but we would like to
                         //   initiate a shut down instead once this happens.
-                        error!(
-                            log,
-                            "ClusterManager XDS client terminated with an error: {}", err
+                        tracing::error!(
+                            %error,
+                            "ClusterManager XDS client terminated with an error"
                         );
                     }
                 });
@@ -196,9 +211,8 @@ impl Server {
     /// This function also spawns the set of worker tasks responsible for consuming packets
     /// off the aforementioned queue and processing them through the filter chain and session
     /// pipeline.
-    fn run_recv_from(&self, args: RunRecvFromArgs) -> JoinHandle<StdResult<(), String>> {
+    fn run_recv_from(&self, args: RunRecvFromArgs) -> JoinHandle<Result<()>> {
         let session_manager = args.session_manager;
-        let log = self.log.clone();
         let proxy_metrics = self.proxy_metrics.clone();
         let session_metrics = self.session_metrics.clone();
 
@@ -218,7 +232,6 @@ impl Server {
                 packet_rx,
                 shutdown_rx: args.shutdown_rx.clone(),
                 receive_config: ProcessDownstreamReceiveConfig {
-                    log: log.clone(),
                     proxy_metrics: proxy_metrics.clone(),
                     session_metrics: session_metrics.clone(),
                     cluster_manager: args.cluster_manager.clone(),
@@ -232,7 +245,7 @@ impl Server {
 
         // Start the worker tasks that pick up received packets from their queue
         // and processes them.
-        Self::spawn_downstream_receive_workers(log.clone(), worker_configs);
+        Self::spawn_downstream_receive_workers(worker_configs);
 
         // Start the background task to receive downstream packets from the socket
         // and place them onto the worker tasks' queue for processing.
@@ -248,26 +261,32 @@ impl Server {
             loop {
                 match socket.recv_from(&mut buf).await {
                     Ok((size, recv_addr)) => {
+                        let timer = proxy_metrics.read_processing_time_seconds.start_timer();
                         let packet_tx = &mut packet_txs[next_worker % num_workers];
                         next_worker += 1;
 
                         if packet_tx
-                            .send((recv_addr, (&buf[..size]).to_vec()))
+                            .send(DownstreamPacket {
+                                source: recv_addr.into(),
+                                contents: (&buf[..size]).to_vec(),
+                                timer,
+                            })
                             .await
                             .is_err()
                         {
                             // We cannot recover from this error since
                             // it implies that the receiver has been dropped.
-                            let reason =
-                                "Failed to send received packet over channel to worker".into();
-                            error!(log, "{}", reason);
-                            return Err(reason);
+                            let error = eyre::eyre!(
+                                "Failed to send received packet over channel to worker"
+                            );
+                            tracing::error!(%error);
+                            return Err(error);
                         }
                     }
-                    err => {
-                        // Socket error, we cannot recover from this so return an error instead.
-                        error!(log, "Error processing receive socket"; "error" => #?err);
-                        return Err(format!("error processing receive socket: {:?}", err));
+                    Err(error) => {
+                        let error = eyre::eyre!(error).wrap_err("Error processing receive socket");
+                        tracing::error!(%error);
+                        return Err(error);
                     }
                 }
             }
@@ -277,10 +296,7 @@ impl Server {
     // For each worker config provided, spawn a background task that sits in a
     // loop, receiving packets from a queue and processing them through
     // the filter chain.
-    fn spawn_downstream_receive_workers(
-        log: Logger,
-        worker_configs: Vec<DownstreamReceiveWorkerConfig>,
-    ) {
+    fn spawn_downstream_receive_workers(worker_configs: Vec<DownstreamReceiveWorkerConfig>) {
         for DownstreamReceiveWorkerConfig {
             worker_id,
             mut packet_rx,
@@ -288,22 +304,20 @@ impl Server {
             receive_config,
         } in worker_configs
         {
-            let log = log.clone();
-
             tokio::spawn(async move {
                 loop {
                     tokio::select! {
                       packet = packet_rx.recv() => {
                         match packet {
-                          Some((recv_addr, packet)) => Self::process_downstream_received_packet((recv_addr, packet), &receive_config).await,
+                          Some(packet) => Self::process_downstream_received_packet(packet, &receive_config).await,
                           None => {
-                            debug!(log, "Worker-{} exiting: work sender channel was closed.", worker_id);
+                            tracing::debug!(id = worker_id, "work sender channel was closed.");
                             return;
                           }
                         }
                       }
                       _ = shutdown_rx.changed() => {
-                        debug!(log, "Worker-{} exiting: received shutdown signal.", worker_id);
+                        tracing::debug!(id = worker_id, "received shutdown signal.");
                         return;
                       }
                     }
@@ -314,16 +328,13 @@ impl Server {
 
     /// Processes a packet by running it through the filter chain.
     async fn process_downstream_received_packet(
-        packet: (SocketAddr, Vec<u8>),
+        packet: DownstreamPacket,
         args: &ProcessDownstreamReceiveConfig,
     ) {
-        let (recv_addr, packet) = packet;
-
-        trace!(
-            args.log,
-            "Packet Received";
-            "from" => recv_addr,
-            "contents" => debug::bytes_to_string(&packet),
+        tracing::trace!(
+            source = %packet.source,
+            contents = %debug::bytes_to_string(&packet.contents),
+            "Packet Received"
         );
 
         let endpoints = match args.cluster_manager.read().get_all_endpoints() {
@@ -338,32 +349,43 @@ impl Server {
             let filter_manager_guard = args.filter_manager.read();
             filter_manager_guard.get_filter_chain()
         };
-        let result = filter_chain.read(ReadContext::new(endpoints, recv_addr, packet));
+        let result = filter_chain.read(ReadContext::new(
+            endpoints,
+            packet.source.clone(),
+            packet.contents,
+        ));
 
         if let Some(response) = result {
             for endpoint in response.endpoints.iter() {
-                Self::session_send_packet(&response.contents, recv_addr, endpoint, args).await;
+                Self::session_send_packet(
+                    &response.contents,
+                    packet.source.clone(),
+                    endpoint,
+                    args,
+                )
+                .await;
             }
         }
+        packet.timer.stop_and_record();
     }
 
     /// Send a packet received from `recv_addr` to an endpoint.
     async fn session_send_packet(
         packet: &[u8],
-        recv_addr: SocketAddr,
+        recv_addr: EndpointAddress,
         endpoint: &Endpoint,
         args: &ProcessDownstreamReceiveConfig,
     ) {
         let session_key = SessionKey {
             source: recv_addr,
-            destination: endpoint.address,
+            dest: endpoint.address.clone(),
         };
 
         // Grab a read lock and find the session.
         let guard = args.session_manager.get_sessions().await;
         if let Some(session) = guard.get(&session_key) {
             // If it exists then send the packet, we're done.
-            Self::session_send_packet_helper(&args.log, session, packet, args.session_ttl).await
+            Self::session_send_packet_helper(session, packet, args.session_ttl).await
         } else {
             // If it does not exist, grab a write lock so that we can create it.
             //
@@ -381,21 +403,19 @@ impl Server {
             if let Some(session) = guard.get(&session_key) {
                 // If the session now exists then we have less work to do,
                 // simply send the packet.
-                Self::session_send_packet_helper(&args.log, session, packet, args.session_ttl)
-                    .await;
+                Self::session_send_packet_helper(session, packet, args.session_ttl).await;
             } else {
                 // Otherwise, create the session and insert into the map.
-                match Session::new(
-                    &args.log,
-                    args.session_metrics.clone(),
-                    args.filter_manager.clone(),
-                    session_key.source,
-                    endpoint.clone(),
-                    args.send_packets.clone(),
-                    args.session_ttl,
-                )
-                .await
-                {
+                let session_args = SessionArgs {
+                    metrics: args.session_metrics.clone(),
+                    proxy_metrics: args.proxy_metrics.clone(),
+                    filter_manager: args.filter_manager.clone(),
+                    source: session_key.source.clone(),
+                    dest: endpoint.clone(),
+                    sender: args.send_packets.clone(),
+                    ttl: args.session_ttl,
+                };
+                match session_args.into_session().await {
                     Ok(session) => {
                         // Insert the session into the map and release the write lock
                         // immediately since we don't want to block other threads while we send
@@ -408,23 +428,17 @@ impl Server {
                         // Grab a read lock to send the packet.
                         let guard = args.session_manager.get_sessions().await;
                         if let Some(session) = guard.get(&session_key) {
-                            Self::session_send_packet_helper(
-                                &args.log,
-                                session,
-                                packet,
-                                args.session_ttl,
-                            )
-                            .await;
+                            Self::session_send_packet_helper(session, packet, args.session_ttl)
+                                .await;
                         } else {
-                            warn!(
-                                args.log,
-                                "Could not find session";
-                                "key" => format!("({}:{})", session_key.source.to_string(), session_key.destination.to_string())
+                            tracing::warn!(
+                                key = %format!("({}:{})", session_key.source, session_key.dest),
+                                "Could not find session"
                             )
                         }
                     }
-                    Err(err) => {
-                        error!(args.log, "Failed to ensure session exists"; "error" => %err);
+                    Err(error) => {
+                        tracing::error!(%error, "Failed to ensure session exists");
                     }
                 }
             }
@@ -432,19 +446,14 @@ impl Server {
     }
 
     // A helper function to push a session's packet on its socket.
-    async fn session_send_packet_helper(
-        log: &Logger,
-        session: &Session,
-        packet: &[u8],
-        ttl: Duration,
-    ) {
+    async fn session_send_packet_helper(session: &Session, packet: &[u8], ttl: Duration) {
         match session.send(packet).await {
             Ok(_) => {
-                if let Err(err) = session.update_expiration(ttl) {
-                    warn!(log, "Error updating session expiration"; "error" => %err)
+                if let Err(error) = session.update_expiration(ttl) {
+                    tracing::warn!(%error, "Error updating session expiration")
                 }
             }
-            Err(err) => error!(log, "Error sending packet from session"; "error" => %err),
+            Err(error) => tracing::error!(%error, "Error sending packet from session"),
         };
     }
 
@@ -453,35 +462,40 @@ impl Server {
     fn run_receive_packet(
         &self,
         socket: Arc<UdpSocket>,
-        mut receive_packets: mpsc::Receiver<Packet>,
+        mut receive_packets: mpsc::Receiver<UpstreamPacket>,
     ) {
-        let log = self.log.clone();
         tokio::spawn(async move {
             while let Some(packet) = receive_packets.recv().await {
-                debug!(
-                    log,
-                    "Sending packet back to origin";
-                    "origin" => packet.dest(),
-                    "contents" => debug::bytes_to_string(packet.contents()),
+                tracing::debug!(
+                    origin = %packet.dest(),
+                    contents = %debug::bytes_to_string(packet.contents()),
+                    "Sending packet back to origin"
                 );
 
-                if let Err(err) = socket.send_to(packet.contents(), &packet.dest()).await {
-                    error!(log, "Error sending packet"; "dest" => %packet.dest(), "error" => %err);
-                }
-            }
-            debug!(log, "Receiver closed");
-        });
-    }
+                let address = match packet.dest().to_socket_addr() {
+                    Ok(address) => address,
+                    Err(error) => {
+                        tracing::error!(dest = %packet.dest(), %error, "Error resolving address");
+                        continue;
+                    }
+                };
 
-    /// log_config outputs a log of what is configured
-    fn log_config(&self) {
-        info!(self.log, "Starting"; "port" => self.config.proxy.port, "proxy_id" => &self.config.proxy.id);
+                if let Err(error) = socket.send_to(packet.contents(), address).await {
+                    tracing::error!(dest = %packet.dest(), %error, "Error sending packet");
+                }
+                packet.stop_and_record();
+            }
+            tracing::debug!("Receiver closed");
+            Ok::<_, eyre::Error>(())
+        });
     }
 
     /// bind binds the local configured port
     async fn bind(port: u16) -> Result<UdpSocket> {
         let addr = SocketAddrV4::new(Ipv4Addr::new(0, 0, 0, 0), port);
-        UdpSocket::bind(addr).await.map_err(Error::Bind)
+        UdpSocket::bind(addr)
+            .await
+            .map_err(|error| eyre::eyre!(error))
     }
 }
 
@@ -491,8 +505,7 @@ mod tests {
     use std::sync::Arc;
     use std::time::{SystemTime, UNIX_EPOCH};
 
-    use prometheus::Registry;
-    use slog::info;
+    use prometheus::{Histogram, HistogramOpts, Registry};
     use tokio::sync::mpsc;
     use tokio::time;
     use tokio::time::timeout;
@@ -503,11 +516,9 @@ mod tests {
     use crate::config::Builder as ConfigBuilder;
     use crate::endpoint::{Endpoint, Endpoints};
     use crate::filters::{manager::FilterManager, FilterChain};
-    use crate::proxy::sessions::Packet;
+    use crate::proxy::sessions::UpstreamPacket;
     use crate::proxy::Builder;
-    use crate::test_utils::{
-        config_with_dummy_endpoint, logger, new_registry, new_test_chain, TestHelper,
-    };
+    use crate::test_utils::{config_with_dummy_endpoint, new_registry, new_test_chain, TestHelper};
 
     use super::*;
 
@@ -518,14 +529,14 @@ mod tests {
         let endpoint1 = t.open_socket_and_recv_single_packet().await;
         let endpoint2 = t.open_socket_and_recv_single_packet().await;
 
-        let local_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)), 12358);
+        let local_addr = (Ipv4Addr::UNSPECIFIED, 12358);
         let config = ConfigBuilder::empty()
-            .with_port(local_addr.port())
+            .with_port(local_addr.1)
             .with_static(
                 vec![],
                 vec![
-                    Endpoint::new(endpoint1.socket.local_addr().unwrap()),
-                    Endpoint::new(endpoint2.socket.local_addr().unwrap()),
+                    Endpoint::new(endpoint1.socket.local_addr().unwrap().into()),
+                    Endpoint::new(endpoint2.socket.local_addr().unwrap().into()),
                 ],
             )
             .build();
@@ -552,7 +563,7 @@ mod tests {
             .with_port(local_addr.port())
             .with_static(
                 vec![],
-                vec![Endpoint::new(endpoint.socket.local_addr().unwrap())],
+                vec![Endpoint::new(endpoint.socket.local_addr().unwrap().into())],
             )
             .build();
         t.run_server_with_config(config);
@@ -570,7 +581,7 @@ mod tests {
     async fn run_with_filter() {
         let mut t = TestHelper::default();
 
-        let registry = new_registry(&logger());
+        let registry = new_registry();
         let endpoint = t.open_socket_and_recv_single_packet().await;
         let local_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)), 12367);
         let config = ConfigBuilder::empty()
@@ -580,7 +591,7 @@ mod tests {
                     name: "TestFilter".to_string(),
                     config: None,
                 }],
-                vec![Endpoint::new(endpoint.socket.local_addr().unwrap())],
+                vec![Endpoint::new(endpoint.socket.local_addr().unwrap().into())],
             )
             .build();
         t.run_server_with_builder(
@@ -633,7 +644,7 @@ mod tests {
         ) -> Result {
             let t = TestHelper::default();
 
-            info!(t.log, "Test"; "name" => name);
+            tracing::info!(%name, "Test");
             let msg = "hello".to_string();
             let endpoint = t.open_socket_and_recv_single_packet().await;
 
@@ -642,13 +653,13 @@ mod tests {
             // need to switch to 127.0.0.1, as the request comes locally
             receive_addr.set_ip("127.0.0.1".parse().unwrap());
 
-            let session_manager = SessionManager::new(t.log.clone(), shutdown_rx.clone());
-            let (send_packets, mut recv_packets) = mpsc::channel::<Packet>(1);
+            let session_manager = SessionManager::new(shutdown_rx.clone());
+            let (send_packets, mut recv_packets) = mpsc::channel::<UpstreamPacket>(1);
 
             let time_increment = 10;
             time::advance(Duration::from_secs(time_increment)).await;
 
-            let endpoint_address = endpoint.socket.local_addr().unwrap();
+            let endpoint_address = endpoint.socket.local_addr().unwrap().into();
 
             let num_workers = 2;
             let mut packet_txs = Vec::with_capacity(num_workers);
@@ -660,20 +671,22 @@ mod tests {
             )
             .unwrap();
             let filter_manager = FilterManager::fixed(chain.clone());
+            let metrics = Arc::new(Metrics::new(registry.clone()));
+            let proxy_metrics = ProxyMetrics::new(&metrics.registry).unwrap();
+
             for worker_id in 0..num_workers {
                 let (packet_tx, packet_rx) = mpsc::channel(num_workers);
                 packet_txs.push(packet_tx);
 
-                let metrics = Arc::new(Metrics::new(&t.log, registry.clone()));
-                let proxy_metrics = ProxyMetrics::new(&metrics.registry).unwrap();
+                let proxy_metrics = proxy_metrics.clone();
                 let session_metrics = SessionMetrics::new(&metrics.registry).unwrap();
+
                 worker_configs.push(DownstreamReceiveWorkerConfig {
                     worker_id,
                     packet_rx,
                     shutdown_rx: shutdown_rx.clone(),
                     receive_config: ProcessDownstreamReceiveConfig {
-                        log: t.log.clone(),
-                        proxy_metrics,
+                        proxy_metrics: proxy_metrics.clone(),
                         session_metrics,
                         cluster_manager: cluster_manager.clone(),
                         filter_manager: filter_manager.clone(),
@@ -684,11 +697,15 @@ mod tests {
                 })
             }
 
-            Server::spawn_downstream_receive_workers(t.log.clone(), worker_configs);
+            Server::spawn_downstream_receive_workers(worker_configs);
 
             for packet_tx in packet_txs {
                 packet_tx
-                    .send((receive_addr, msg.as_bytes().to_vec()))
+                    .send(DownstreamPacket {
+                        source: receive_addr.into(),
+                        contents: msg.as_bytes().to_vec(),
+                        timer: proxy_metrics.read_processing_time_seconds.start_timer(),
+                    })
                     .await
                     .unwrap();
             }
@@ -700,7 +717,11 @@ mod tests {
 
             let map = session_manager.get_sessions().await;
             assert_eq!(expected.session_len, map.len());
-            let build_key = (receive_addr, endpoint.socket.local_addr().unwrap()).into();
+            let build_key = (
+                receive_addr.into(),
+                endpoint.socket.local_addr().unwrap().into(),
+            )
+                .into();
             assert!(map.contains_key(&build_key));
             let session = map.get(&build_key).unwrap();
             let now_secs = SystemTime::now()
@@ -710,6 +731,14 @@ mod tests {
             let diff = session.expiration() - now_secs;
             assert!((5..11).contains(&diff));
 
+            assert_eq!(
+                num_workers as u64,
+                proxy_metrics
+                    .read_processing_time_seconds
+                    .get_sample_count(),
+                "One packet is sent for each worker, and we should have a sample for each"
+            );
+
             Result {
                 msg: result,
                 addr: receive_addr,
@@ -755,8 +784,8 @@ mod tests {
         let msg = "hello";
         let endpoint = t.open_socket_and_recv_single_packet().await;
         let socket = t.create_socket().await;
-        let session_manager = SessionManager::new(t.log.clone(), shutdown_rx.clone());
-        let (send_packets, mut recv_packets) = mpsc::channel::<Packet>(1);
+        let session_manager = SessionManager::new(shutdown_rx.clone());
+        let (send_packets, mut recv_packets) = mpsc::channel::<UpstreamPacket>(1);
 
         let config = Arc::new(config_with_dummy_endpoint().build());
         let server = Builder::from(config).validate().unwrap().build();
@@ -765,7 +794,10 @@ mod tests {
         server.run_recv_from(RunRecvFromArgs {
             cluster_manager: ClusterManager::fixed(
                 &registry,
-                Endpoints::new(vec![Endpoint::new(endpoint.socket.local_addr().unwrap())]).unwrap(),
+                Endpoints::new(vec![Endpoint::new(
+                    endpoint.socket.local_addr().unwrap().into(),
+                )])
+                .unwrap(),
             )
             .unwrap(),
             filter_manager: FilterManager::fixed(Arc::new(
@@ -795,15 +827,18 @@ mod tests {
     async fn run_receive_packet() {
         let t = TestHelper::default();
 
+        let histogram = Histogram::with_opts(HistogramOpts::new("test", "test")).unwrap();
+
         let msg = "hello";
 
         // without a filter
-        let (send_packet, recv_packet) = mpsc::channel::<Packet>(1);
+        let (send_packet, recv_packet) = mpsc::channel::<UpstreamPacket>(1);
         let endpoint = t.open_socket_and_recv_single_packet().await;
         if send_packet
-            .send(Packet::new(
-                endpoint.socket.local_addr().unwrap(),
+            .send(UpstreamPacket::new(
+                endpoint.socket.local_addr().unwrap().into(),
                 msg.as_bytes().to_vec(),
+                histogram.start_timer(),
             ))
             .await
             .is_err()
@@ -814,5 +849,10 @@ mod tests {
         let server = Builder::from(config).validate().unwrap().build();
         server.run_receive_packet(endpoint.socket, recv_packet);
         assert_eq!(msg, endpoint.packet_rx.await.unwrap());
+        assert_eq!(
+            1_u64,
+            histogram.get_sample_count(),
+            "one packet sent, so there should be one sample"
+        );
     }
 }
