@@ -22,10 +22,9 @@ use crate::{
         manager::{FilterManager, ListenerManagerArgs, SharedFilterManager},
         FilterChain, FilterRegistry,
     },
-    xds::ads_client::{AdsClient, ClusterUpdate, ExecutionResult, UPDATES_CHANNEL_BUFFER_SIZE},
+    xds::ads_client::{AdsClient, ClusterUpdate, UPDATES_CHANNEL_BUFFER_SIZE},
 };
 use prometheus::Registry;
-use slog::{o, warn, Logger};
 use std::sync::Arc;
 use tokio::sync::{mpsc, oneshot, watch};
 
@@ -39,7 +38,7 @@ pub(super) struct StaticResourceManagers {
 pub(super) struct DynamicResourceManagers {
     pub(super) cluster_manager: SharedClusterManager,
     pub(super) filter_manager: SharedFilterManager,
-    pub(super) execution_result_rx: oneshot::Receiver<ExecutionResult>,
+    pub(super) execution_result_rx: oneshot::Receiver<crate::Result<()>>,
 }
 
 impl StaticResourceManagers {
@@ -50,7 +49,7 @@ impl StaticResourceManagers {
     ) -> Result<StaticResourceManagers, InitializeError> {
         Ok(Self {
             cluster_manager: ClusterManager::fixed(metrics_registry, endpoints)
-                .map_err(|err| InitializeError::Message(format!("{:?}", err)))?,
+                .map_err(|err| InitializeError::Message(format!("{err:?}")))?,
             filter_manager: FilterManager::fixed(filter_chain),
         })
     }
@@ -58,27 +57,23 @@ impl StaticResourceManagers {
 
 /// Contains arguments to the `spawn_ads_client` function.
 struct SpawnAdsClient {
-    log: Logger,
     metrics_registry: Registry,
     node_id: String,
     management_servers: Vec<ManagementServer>,
     cluster_updates_tx: mpsc::Sender<ClusterUpdate>,
     listener_manager_args: ListenerManagerArgs,
-    execution_result_tx: oneshot::Sender<ExecutionResult>,
+    execution_result_tx: oneshot::Sender<crate::Result<()>>,
     shutdown_rx: watch::Receiver<()>,
 }
 
 impl DynamicResourceManagers {
     pub(super) async fn new(
-        base_logger: Logger,
         xds_node_id: String,
         metrics_registry: Registry,
         filter_registry: FilterRegistry,
         management_servers: Vec<ManagementServer>,
         shutdown_rx: watch::Receiver<()>,
     ) -> Result<DynamicResourceManagers, InitializeError> {
-        let log = base_logger.new(o!("source" => "server::DynamicResourceManager"));
-
         let (cluster_updates_tx, cluster_updates_rx) = Self::cluster_updates_channel();
         let (filter_chain_updates_tx, filter_chain_updates_rx) =
             Self::filter_chain_updates_channel();
@@ -89,9 +84,8 @@ impl DynamicResourceManagers {
             filter_chain_updates_tx,
         );
 
-        let (execution_result_tx, execution_result_rx) = oneshot::channel::<ExecutionResult>();
+        let (execution_result_tx, execution_result_rx) = oneshot::channel::<crate::Result<()>>();
         Self::spawn_ads_client(SpawnAdsClient {
-            log: log.clone(),
             metrics_registry: metrics_registry.clone(),
             node_id: xds_node_id,
             management_servers,
@@ -101,21 +95,13 @@ impl DynamicResourceManagers {
             shutdown_rx: shutdown_rx.clone(),
         })?;
 
-        let cluster_manager = ClusterManager::dynamic(
-            base_logger.new(o!("source" => "ClusterManager")),
-            &metrics_registry,
-            cluster_updates_rx,
-            shutdown_rx.clone(),
-        )
-        .map_err(|err| InitializeError::Message(format!("{:?}", err)))?;
+        let cluster_manager =
+            ClusterManager::dynamic(&metrics_registry, cluster_updates_rx, shutdown_rx.clone())
+                .map_err(|err| InitializeError::Message(format!("{err:?}")))?;
 
-        let filter_manager = FilterManager::dynamic(
-            base_logger.new(o!("source" => "FilterManager")),
-            &metrics_registry,
-            filter_chain_updates_rx,
-            shutdown_rx,
-        )
-        .map_err(|err| InitializeError::Message(format!("{:?}", err)))?;
+        let filter_manager =
+            FilterManager::dynamic(&metrics_registry, filter_chain_updates_rx, shutdown_rx)
+                .map_err(|err| InitializeError::Message(format!("{err:?}")))?;
 
         Ok(Self {
             cluster_manager,
@@ -129,7 +115,6 @@ impl DynamicResourceManagers {
     // as well as execution result after termination are sent on the passed-in channels.
     fn spawn_ads_client(args: SpawnAdsClient) -> Result<(), InitializeError> {
         let SpawnAdsClient {
-            log,
             metrics_registry,
             node_id,
             management_servers,
@@ -139,8 +124,8 @@ impl DynamicResourceManagers {
             shutdown_rx,
         } = args;
 
-        let client = AdsClient::new(log.clone(), &metrics_registry).map_err(|err| {
-            InitializeError::Message(format!("failed to initialize xDS client: {:?}", err))
+        let client = AdsClient::new(&metrics_registry).map_err(|err| {
+            InitializeError::Message(format!("failed to initialize xDS client: {err:?}"))
         })?;
         tokio::spawn(async move {
             let result = client
@@ -154,7 +139,9 @@ impl DynamicResourceManagers {
                 .await;
             execution_result_tx
                 .send(result)
-                .map_err(|_err| warn!(log, "Failed to send ADS client execution result on channel"))
+                .map_err(|_err| {
+                    tracing::warn!("Failed to send ADS client execution result on channel")
+                })
                 .ok();
         });
 
@@ -178,7 +165,6 @@ mod tests {
     use super::DynamicResourceManagers;
     use crate::config::ManagementServer;
     use crate::filters::{manager::ListenerManagerArgs, FilterRegistry};
-    use crate::test_utils::logger;
 
     use std::time::Duration;
 
@@ -199,7 +185,6 @@ mod tests {
         let (_shutdown_tx, shutdown_rx) = watch::channel(());
 
         DynamicResourceManagers::spawn_ads_client(SpawnAdsClient {
-            log: logger(),
             metrics_registry: Registry::default(),
             node_id: "id".into(),
             management_servers: vec![ManagementServer {
