@@ -14,21 +14,29 @@
  * limitations under the License.
  */
 
-use std::net::{Ipv4Addr, SocketAddr, SocketAddrV4};
-use std::sync::atomic::{AtomicU64, Ordering};
-use std::sync::Arc;
-use std::time::{SystemTime, UNIX_EPOCH};
+use prometheus::HistogramTimer;
+use std::{
+    sync::{
+        atomic::{AtomicU64, Ordering},
+        Arc,
+    },
+    time::{SystemTime, UNIX_EPOCH},
+};
 
-use slog::{debug, error, o, trace, warn, Logger};
-use tokio::net::UdpSocket;
-use tokio::select;
-use tokio::sync::{mpsc, watch};
-use tokio::time::{Duration, Instant};
+use tokio::{
+    net::UdpSocket,
+    select,
+    sync::{mpsc, watch},
+    time::{Duration, Instant},
+};
 
 use crate::{
-    endpoint::Endpoint,
+    endpoint::{Endpoint, EndpointAddress},
     filters::{manager::SharedFilterManager, Filter, WriteContext},
-    proxy::sessions::{error::Error, metrics::Metrics},
+    proxy::{
+        server::metrics::Metrics as ProxyMetrics,
+        sessions::{error::Error, metrics::Metrics},
+    },
     utils::debug,
 };
 
@@ -36,16 +44,16 @@ type Result<T> = std::result::Result<T, Error>;
 
 /// Session encapsulates a UDP stream session
 pub struct Session {
-    log: Logger,
     metrics: Metrics,
+    proxy_metrics: ProxyMetrics,
     filter_manager: SharedFilterManager,
     /// created_at is time at which the session was created
     created_at: Instant,
     socket: Arc<UdpSocket>,
     /// dest is where to send data to
     dest: Endpoint,
-    /// from is the original sender
-    from: SocketAddr,
+    /// address of original sender
+    source: EndpointAddress,
     /// The time at which the session is considered expired and can be removed.
     expiration: Arc<AtomicU64>,
     /// a channel to broadcast on if we are shutting down this Session
@@ -55,16 +63,13 @@ pub struct Session {
 // A (source, destination) address pair that uniquely identifies a session.
 #[derive(Clone, Eq, Hash, PartialEq, Debug, PartialOrd, Ord)]
 pub struct SessionKey {
-    pub source: SocketAddr,
-    pub destination: SocketAddr,
+    pub source: EndpointAddress,
+    pub dest: EndpointAddress,
 }
 
-impl From<(SocketAddr, SocketAddr)> for SessionKey {
-    fn from(pair: (SocketAddr, SocketAddr)) -> Self {
-        SessionKey {
-            source: pair.0,
-            destination: pair.1,
-        }
+impl From<(EndpointAddress, EndpointAddress)> for SessionKey {
+    fn from((source, dest): (EndpointAddress, EndpointAddress)) -> Self {
+        SessionKey { source, dest }
     }
 }
 
@@ -73,67 +78,86 @@ struct ReceivedPacketContext<'a> {
     packet: &'a [u8],
     filter_manager: SharedFilterManager,
     endpoint: &'a Endpoint,
-    from: SocketAddr,
-    to: SocketAddr,
+    source: EndpointAddress,
+    dest: EndpointAddress,
+    timer: HistogramTimer,
 }
 
-/// Packet represents a packet that needs to go somewhere
-pub struct Packet {
-    dest: SocketAddr,
+/// Represents a data packet received by an Endpoint to this Session.
+pub struct UpstreamPacket {
+    dest: EndpointAddress,
     contents: Vec<u8>,
+    timer: HistogramTimer,
 }
 
-impl Packet {
-    pub fn new(dest: SocketAddr, contents: Vec<u8>) -> Packet {
-        Packet { dest, contents }
+impl UpstreamPacket {
+    pub fn new(dest: EndpointAddress, contents: Vec<u8>, timer: HistogramTimer) -> UpstreamPacket {
+        UpstreamPacket {
+            dest,
+            contents,
+            timer,
+        }
     }
 
-    pub fn dest(&self) -> SocketAddr {
-        self.dest
+    pub fn dest(&self) -> &EndpointAddress {
+        &self.dest
     }
 
-    pub fn contents(&self) -> &Vec<u8> {
+    pub fn contents(&self) -> &[u8] {
         &self.contents
     }
+
+    /// stop and record the stored [HistogramTimer]
+    pub fn stop_and_record(self) {
+        self.timer.stop_and_record();
+    }
+}
+
+pub struct SessionArgs {
+    pub metrics: Metrics,
+    pub proxy_metrics: ProxyMetrics,
+    pub filter_manager: SharedFilterManager,
+    pub source: EndpointAddress,
+    pub dest: Endpoint,
+    pub sender: mpsc::Sender<UpstreamPacket>,
+    pub ttl: Duration,
+}
+
+impl SessionArgs {
+    /// Creates a new Session, and starts the process of receiving udp sockets
+    /// from its ephemeral port from endpoint(s)
+    pub async fn into_session(self) -> Result<Session> {
+        Session::new(self).await
+    }
 }
 
 impl Session {
-    /// new creates a new Session, and starts the process of receiving udp sockets
-    /// from its ephemeral port from endpoint(s)
-    pub async fn new(
-        base: &Logger,
-        metrics: Metrics,
-        filter_manager: SharedFilterManager,
-        from: SocketAddr,
-        dest: Endpoint,
-        sender: mpsc::Sender<Packet>,
-        ttl: Duration,
-    ) -> Result<Self> {
-        let log = base
-            .new(o!("source" => "proxy::Session", "from" => from, "dest_address" => dest.address));
-        let addr = SocketAddrV4::new(Ipv4Addr::new(0, 0, 0, 0), 0);
+    /// internal constructor for a Session from SessionArgs
+    async fn new(args: SessionArgs) -> Result<Self> {
+        let addr = (std::net::Ipv4Addr::UNSPECIFIED, 0);
         let socket = Arc::new(UdpSocket::bind(addr).await.map_err(Error::BindUdpSocket)?);
         let (shutdown_tx, shutdown_rx) = watch::channel::<()>(());
 
         let expiration = Arc::new(AtomicU64::new(0));
-        Self::do_update_expiration(&expiration, ttl)?;
+        Self::do_update_expiration(&expiration, args.ttl)?;
 
         let s = Session {
-            metrics,
-            log,
-            filter_manager,
+            metrics: args.metrics,
+            proxy_metrics: args.proxy_metrics,
+            filter_manager: args.filter_manager,
             socket: socket.clone(),
-            from,
-            dest,
+            source: args.source,
+            dest: args.dest,
             created_at: Instant::now(),
             expiration,
             shutdown_tx,
         };
-        debug!(s.log, "Session created");
+
+        tracing::debug!(source = %s.source, dest = ?s.dest, "Session created");
 
         s.metrics.sessions_total.inc();
         s.metrics.active_sessions.inc();
-        s.run(ttl, socket, sender, shutdown_rx);
+        s.run(args.ttl, socket, args.sender, shutdown_rx);
         Ok(s)
     }
 
@@ -142,31 +166,31 @@ impl Session {
         &self,
         ttl: Duration,
         socket: Arc<UdpSocket>,
-        mut sender: mpsc::Sender<Packet>,
+        mut sender: mpsc::Sender<UpstreamPacket>,
         mut shutdown_rx: watch::Receiver<()>,
     ) {
-        let log = self.log.clone();
-        let from = self.from;
+        let source = self.source.clone();
         let expiration = self.expiration.clone();
         let filter_manager = self.filter_manager.clone();
         let endpoint = self.dest.clone();
         let metrics = self.metrics.clone();
+        let proxy_metrics = self.proxy_metrics.clone();
         tokio::spawn(async move {
             let mut buf: Vec<u8> = vec![0; 65535];
             loop {
-                debug!(log, "Awaiting incoming packet");
+                tracing::debug!(source = %source, dest = ?endpoint, "Awaiting incoming packet");
+
                 select! {
                     received = socket.recv_from(&mut buf) => {
                         match received {
-                            Err(err) => {
+                            Err(error) => {
                                 metrics.rx_errors_total.inc();
-                                error!(log, "Error receiving packet"; "error" => %err);
+                                tracing::error!(%error, %source, dest = ?endpoint, "Error receiving packet");
                             },
                             Ok((size, recv_addr)) => {
                                 metrics.rx_bytes_total.inc_by(size as u64);
                                 metrics.rx_packets_total.inc();
                                 Session::process_recv_packet(
-                                    &log,
                                     &metrics,
                                     &mut sender,
                                     &expiration,
@@ -175,14 +199,15 @@ impl Session {
                                         filter_manager: filter_manager.clone(),
                                         packet: &buf[..size],
                                         endpoint: &endpoint,
-                                        from: recv_addr,
-                                        to: from,
+                                        source: recv_addr.into(),
+                                        dest: source.clone(),
+                                        timer: proxy_metrics.write_processing_time_seconds.start_timer(),
                                     }).await
                             }
                         };
                     }
                     _ = shutdown_rx.changed() => {
-                        debug!(log, "Closing Session");
+                        tracing::debug!(%source, dest = ?endpoint, "Closing Session");
                         return;
                     }
                 };
@@ -198,16 +223,15 @@ impl Session {
     /// key returns the key to be used for this session in a SessionMap
     pub fn key(&self) -> SessionKey {
         SessionKey {
-            source: self.from,
-            destination: self.dest.address,
+            source: self.source.clone(),
+            dest: self.dest.address.clone(),
         }
     }
 
     /// process_recv_packet processes a packet that is received by this session.
     async fn process_recv_packet(
-        log: &Logger,
         metrics: &Metrics,
-        sender: &mut mpsc::Sender<Packet>,
+        sender: &mut mpsc::Sender<UpstreamPacket>,
         expiration: &Arc<AtomicU64>,
         ttl: Duration,
         packet_ctx: ReceivedPacketContext<'_>,
@@ -216,29 +240,35 @@ impl Session {
             packet,
             filter_manager,
             endpoint,
-            from,
-            to,
+            source: from,
+            dest: to,
+            timer,
         } = packet_ctx;
 
-        trace!(log, "Received packet"; "from" => from,
-            "endpoint_addr" => &endpoint.address,
-            "contents" => debug::bytes_to_string(packet));
+        tracing::trace!(%from, dest = %endpoint.address, contents = %debug::bytes_to_string(packet), "Received packet");
 
-        if let Err(err) = Session::do_update_expiration(expiration, ttl) {
-            warn!(log, "Error updating session expiration"; "error" => %err)
+        if let Err(error) = Session::do_update_expiration(expiration, ttl) {
+            tracing::warn!(%error, "Error updating session expiration")
         }
 
         let filter_chain = {
             let filter_manager_guard = filter_manager.read();
             filter_manager_guard.get_filter_chain()
         };
-        if let Some(response) =
-            filter_chain.write(WriteContext::new(endpoint, from, to, packet.to_vec()))
-        {
-            if let Err(err) = sender.send(Packet::new(to, response.contents)).await {
-                metrics.rx_errors_total.inc();
-                error!(log, "Error sending packet to channel"; "error" => %err);
-            }
+
+        let write_result: futures::future::OptionFuture<_> = filter_chain
+            .write(WriteContext::new(
+                endpoint,
+                from,
+                to.clone(),
+                packet.to_vec(),
+            ))
+            .map(|response| sender.send(UpstreamPacket::new(to, response.contents, timer)))
+            .into();
+
+        if let Some(Err(error)) = write_result.await {
+            metrics.rx_errors_total.inc();
+            tracing::error!(%error, "Error sending packet to channel");
         } else {
             metrics.packets_dropped_total.inc();
         }
@@ -273,10 +303,11 @@ impl Session {
     }
 
     /// Sends a packet to the Session's dest.
-    pub async fn send(&self, buf: &[u8]) -> Result<Option<usize>> {
-        trace!(self.log, "Sending packet";
-        "dest_address" => &self.dest.address,
-        "contents" => debug::bytes_to_string(buf));
+    pub async fn send(&self, buf: &[u8]) -> crate::Result<Option<usize>> {
+        tracing::trace!(
+        dest_address = %self.dest.address,
+        contents = %debug::bytes_to_string(buf),
+        "Sending packet");
 
         self.do_send(buf)
             .await
@@ -287,14 +318,17 @@ impl Session {
             })
             .map_err(|err| {
                 self.metrics.tx_errors_total.inc();
-                Error::SendToDst(err)
+                eyre::eyre!(err).wrap_err("Error sending to destination.")
             })
     }
 
     /// Sends `buf` to the session's destination address. On success, returns
     /// the number of bytes written.
-    pub async fn do_send(&self, buf: &[u8]) -> std::result::Result<usize, std::io::Error> {
-        self.socket.send_to(buf, &self.dest.address).await
+    pub async fn do_send(&self, buf: &[u8]) -> crate::Result<usize> {
+        self.socket
+            .send_to(buf, &self.dest.address.to_socket_addr()?)
+            .await
+            .map_err(|error| eyre::eyre!(error))
     }
 }
 
@@ -306,51 +340,58 @@ impl Drop for Session {
             .observe(self.created_at.elapsed().as_secs() as f64);
 
         if let Err(error) = self.shutdown_tx.send(()) {
-            warn!(self.log, "Error sending session shutdown signal"; "error" => error.to_string());
+            tracing::warn!(%error, "Error sending session shutdown signal");
         }
 
-        debug!(self.log, "Session closed"; "from" => self.from, "dest_address" => &self.dest.address);
+        tracing::debug!(source = %self.source, dest_address = %self.dest.address, "Session closed");
     }
 }
 
 #[cfg(test)]
 mod tests {
-    use std::str::from_utf8;
-    use std::sync::atomic::{AtomicU64, Ordering};
-    use std::sync::Arc;
-    use std::time::{Duration, SystemTime, UNIX_EPOCH};
+    use std::{
+        net::Ipv4Addr,
+        str::from_utf8,
+        sync::{
+            atomic::{AtomicU64, Ordering},
+            Arc,
+        },
+        time::{Duration, SystemTime, UNIX_EPOCH},
+    };
 
-    use super::{Metrics, Packet, Session};
+    use super::{Metrics, ProxyMetrics, Session, UpstreamPacket};
 
-    use prometheus::Registry;
+    use prometheus::{Histogram, HistogramOpts, Registry};
     use tokio::time::timeout;
 
     use crate::filters::FilterChain;
     use crate::test_utils::{new_test_chain, TestHelper};
 
-    use crate::endpoint::Endpoint;
+    use crate::endpoint::{Endpoint, EndpointAddress};
     use crate::filters::manager::FilterManager;
-    use crate::proxy::sessions::session::ReceivedPacketContext;
+    use crate::proxy::sessions::session::{ReceivedPacketContext, SessionArgs};
     use tokio::sync::mpsc;
 
     #[tokio::test]
     async fn session_new() {
         let t = TestHelper::default();
         let socket = t.create_socket().await;
-        let addr = socket.local_addr().unwrap();
-        let endpoint = Endpoint::new(addr);
-        let (send_packet, mut recv_packet) = mpsc::channel::<Packet>(5);
+        let addr: EndpointAddress = socket.local_addr().unwrap().into();
+        let endpoint = Endpoint::new(addr.clone());
+        let (send_packet, mut recv_packet) = mpsc::channel::<UpstreamPacket>(5);
         let registry = Registry::default();
 
-        let sess = Session::new(
-            &t.log,
-            Metrics::new(&registry).unwrap(),
-            FilterManager::fixed(Arc::new(FilterChain::new(vec![], &registry).unwrap())),
-            addr,
-            endpoint,
-            send_packet,
-            Duration::from_secs(20),
-        )
+        let sess = Session::new(SessionArgs {
+            metrics: Metrics::new(&registry).unwrap(),
+            proxy_metrics: ProxyMetrics::new(&registry).unwrap(),
+            filter_manager: FilterManager::fixed(Arc::new(
+                FilterChain::new(vec![], &registry).unwrap(),
+            )),
+            source: addr.clone(),
+            dest: endpoint,
+            sender: send_packet,
+            ttl: Duration::from_secs(20),
+        })
         .await
         .unwrap();
 
@@ -386,21 +427,23 @@ mod tests {
         let msg = "hello";
 
         // without a filter
-        let (sender, _) = mpsc::channel::<Packet>(1);
+        let (sender, _) = mpsc::channel::<UpstreamPacket>(1);
         let ep = t.open_socket_and_recv_single_packet().await;
-        let addr = ep.socket.local_addr().unwrap();
-        let endpoint = Endpoint::new(addr);
+        let addr: EndpointAddress = ep.socket.local_addr().unwrap().into();
+        let endpoint = Endpoint::new(addr.clone());
         let registry = Registry::default();
 
-        let session = Session::new(
-            &t.log,
-            Metrics::new(&Registry::default()).unwrap(),
-            FilterManager::fixed(Arc::new(FilterChain::new(vec![], &registry).unwrap())),
-            addr,
-            endpoint.clone(),
+        let session = Session::new(SessionArgs {
+            metrics: Metrics::new(&registry).unwrap(),
+            proxy_metrics: ProxyMetrics::new(&registry).unwrap(),
+            filter_manager: FilterManager::fixed(Arc::new(
+                FilterChain::new(vec![], &registry).unwrap(),
+            )),
+            source: addr,
+            dest: endpoint.clone(),
             sender,
-            Duration::from_millis(1000),
-        )
+            ttl: Duration::from_millis(1000),
+        })
         .await
         .unwrap();
         session.send(msg.as_bytes()).await.unwrap();
@@ -409,13 +452,13 @@ mod tests {
 
     #[tokio::test]
     async fn process_recv_packet() {
-        let t = TestHelper::default();
         let registry = Registry::default();
+        let histogram = Histogram::with_opts(HistogramOpts::new("test", "test")).unwrap();
 
         let chain = Arc::new(FilterChain::new(vec![], &registry).unwrap());
         let endpoint = Endpoint::new("127.0.1.1:80".parse().unwrap());
-        let dest = "127.0.0.1:88".parse().unwrap();
-        let (mut sender, mut receiver) = mpsc::channel::<Packet>(10);
+        let dest: EndpointAddress = (Ipv4Addr::LOCALHOST, 88).into();
+        let (mut sender, mut receiver) = mpsc::channel::<UpstreamPacket>(10);
         let expiration = Arc::new(AtomicU64::new(
             SystemTime::now()
                 .duration_since(UNIX_EPOCH)
@@ -427,7 +470,6 @@ mod tests {
         // first test with no filtering
         let msg = "hello";
         Session::process_recv_packet(
-            &t.log,
             &Metrics::new(&Registry::default()).unwrap(),
             &mut sender,
             &expiration,
@@ -436,8 +478,9 @@ mod tests {
                 packet: msg.as_bytes(),
                 filter_manager: FilterManager::fixed(chain),
                 endpoint: &endpoint,
-                from: endpoint.address,
-                to: dest,
+                source: endpoint.address.clone(),
+                dest: dest.clone(),
+                timer: histogram.start_timer(),
             },
         )
         .await;
@@ -461,7 +504,6 @@ mod tests {
         let registry = Registry::default();
         let chain = new_test_chain(&registry);
         Session::process_recv_packet(
-            &t.log,
             &Metrics::new(&registry).unwrap(),
             &mut sender,
             &expiration,
@@ -470,8 +512,9 @@ mod tests {
                 filter_manager: FilterManager::fixed(chain),
                 packet: msg.as_bytes(),
                 endpoint: &endpoint,
-                from: endpoint.address,
-                to: dest,
+                source: endpoint.address.clone(),
+                dest: dest.clone(),
+                timer: histogram.start_timer(),
             },
         )
         .await;
@@ -492,20 +535,22 @@ mod tests {
     async fn session_new_metrics() {
         let t = TestHelper::default();
         let ep = t.open_socket_and_recv_single_packet().await;
-        let addr = ep.socket.local_addr().unwrap();
-        let endpoint = Endpoint::new(addr);
-        let (send_packet, _) = mpsc::channel::<Packet>(5);
+        let addr: EndpointAddress = ep.socket.local_addr().unwrap().into();
+        let endpoint = Endpoint::new(addr.clone());
+        let (send_packet, _) = mpsc::channel::<UpstreamPacket>(5);
         let registry = Registry::default();
 
-        let session = Session::new(
-            &t.log,
-            Metrics::new(&Registry::default()).unwrap(),
-            FilterManager::fixed(Arc::new(FilterChain::new(vec![], &registry).unwrap())),
-            addr,
-            endpoint,
-            send_packet,
-            Duration::from_secs(10),
-        )
+        let session = Session::new(SessionArgs {
+            metrics: Metrics::new(&registry).unwrap(),
+            proxy_metrics: ProxyMetrics::new(&registry).unwrap(),
+            filter_manager: FilterManager::fixed(Arc::new(
+                FilterChain::new(vec![], &registry).unwrap(),
+            )),
+            source: addr,
+            dest: endpoint,
+            sender: send_packet,
+            ttl: Duration::from_secs(10),
+        })
         .await
         .unwrap();
 
@@ -517,19 +562,21 @@ mod tests {
     async fn send_to_metrics() {
         let t = TestHelper::default();
 
-        let (sender, _) = mpsc::channel::<Packet>(1);
+        let (sender, _) = mpsc::channel::<UpstreamPacket>(1);
         let endpoint = t.open_socket_and_recv_single_packet().await;
-        let addr = endpoint.socket.local_addr().unwrap();
+        let addr: EndpointAddress = endpoint.socket.local_addr().unwrap().into();
         let registry = Registry::default();
-        let session = Session::new(
-            &t.log,
-            Metrics::new(&registry).unwrap(),
-            FilterManager::fixed(Arc::new(FilterChain::new(vec![], &registry).unwrap())),
-            addr,
-            Endpoint::new(addr),
+        let session = Session::new(SessionArgs {
+            metrics: Metrics::new(&registry).unwrap(),
+            proxy_metrics: ProxyMetrics::new(&registry).unwrap(),
+            filter_manager: FilterManager::fixed(Arc::new(
+                FilterChain::new(vec![], &registry).unwrap(),
+            )),
+            source: addr.clone(),
+            dest: Endpoint::new(addr),
             sender,
-            Duration::from_secs(10),
-        )
+            ttl: Duration::from_secs(10),
+        })
         .await
         .unwrap();
         session.send(b"hello").await.unwrap();
@@ -542,19 +589,21 @@ mod tests {
     #[tokio::test]
     async fn session_drop_metrics() {
         let t = TestHelper::default();
-        let (send_packet, _) = mpsc::channel::<Packet>(5);
+        let (send_packet, _) = mpsc::channel::<UpstreamPacket>(5);
         let endpoint = t.open_socket_and_recv_single_packet().await;
-        let addr = endpoint.socket.local_addr().unwrap();
+        let addr: EndpointAddress = endpoint.socket.local_addr().unwrap().into();
         let registry = Registry::default();
-        let session = Session::new(
-            &t.log,
-            Metrics::new(&registry).unwrap(),
-            FilterManager::fixed(Arc::new(FilterChain::new(vec![], &registry).unwrap())),
-            addr,
-            Endpoint::new(addr),
-            send_packet,
-            Duration::from_secs(10),
-        )
+        let session = Session::new(SessionArgs {
+            metrics: Metrics::new(&registry).unwrap(),
+            proxy_metrics: ProxyMetrics::new(&registry).unwrap(),
+            filter_manager: FilterManager::fixed(Arc::new(
+                FilterChain::new(vec![], &registry).unwrap(),
+            )),
+            source: addr.clone(),
+            dest: Endpoint::new(addr),
+            sender: send_packet,
+            ttl: Duration::from_secs(10),
+        })
         .await
         .unwrap();
 
