@@ -16,46 +16,30 @@
 
 use std::sync::Arc;
 
-use slog::{debug, info, o};
 use tokio::{signal, sync::watch};
+use tracing::{debug, info, span, Level};
 
 use crate::{
     config::Config,
     filters::{DynFilterFactory, FilterRegistry, FilterSet},
     proxy::Builder,
+    Result,
 };
 
 #[cfg(doc)]
 use crate::filters::FilterFactory;
 
-pub type Error = Box<dyn std::error::Error>;
-
-/// Calls [`run`] with the [`Config`] found by [`Config::find`] and the
-/// default [`FilterSet`].
-pub async fn run(
-    filter_factories: impl IntoIterator<Item = DynFilterFactory>,
-) -> Result<(), Error> {
-    let log = crate::proxy::logger();
-    run_with_config(
-        log.clone(),
-        Config::find(&log, None).map(Arc::new)?,
-        filter_factories,
-    )
-    .await
-}
-
 /// Start and run a proxy. Any passed in [`FilterFactory`]s are included
 /// alongside the default filter factories.
-pub async fn run_with_config(
-    base_log: slog::Logger,
-    config: Arc<Config>,
+pub async fn run(
+    config: Config,
     filter_factories: impl IntoIterator<Item = DynFilterFactory>,
-) -> Result<(), Error> {
-    let log = base_log.new(o!("source" => "run"));
-    let server = Builder::from(config)
-        .with_log(base_log)
+) -> Result<()> {
+    let span = span!(Level::INFO, "source::run");
+    let _enter = span.enter();
+
+    let server = Builder::from(Arc::new(config))
         .with_filter_registry(FilterRegistry::new(FilterSet::default_with(
-            &log,
             filter_factories.into_iter(),
         )))
         .validate()?
@@ -65,7 +49,6 @@ pub async fn run_with_config(
     let mut sig_term_fut = signal::unix::signal(signal::unix::SignalKind::terminate())?;
 
     let (shutdown_tx, shutdown_rx) = watch::channel::<()>(());
-    let signal_log = log.clone();
     tokio::spawn(async move {
         #[cfg(target_os = "linux")]
         let sig_term = sig_term_fut.recv();
@@ -74,22 +57,22 @@ pub async fn run_with_config(
 
         tokio::select! {
             _ = signal::ctrl_c() => {
-                debug!(signal_log, "Received SIGINT")
+                debug!("Received SIGINT")
             }
             _ = sig_term => {
-                debug!(signal_log, "Received SIGTERM")
+                debug!("Received SIGTERM")
             }
         }
 
-        info!(signal_log, "Shutting down");
+        info!("Shutting down");
         // Don't unwrap in order to ensure that we execute
         // any subsequent shutdown tasks.
         shutdown_tx.send(()).ok();
     });
 
     if let Err(err) = server.run(shutdown_rx).await {
-        info!(log, "Shutting down with error"; "error" => %err);
-        Err(Error::from(err))
+        info! (error = %err, "Shutting down with error");
+        Err(err)
     } else {
         Ok(())
     }
