@@ -19,14 +19,13 @@ use std::net::{Ipv4Addr, SocketAddr, SocketAddrV4};
 use std::str::from_utf8;
 use std::sync::Arc;
 
-use slog::{o, warn, Drain, Logger};
-use slog_term::{FullFormat, PlainSyncDecorator};
 use tokio::net::UdpSocket;
 use tokio::sync::{mpsc, oneshot, watch};
 
 use crate::config::{Builder as ConfigBuilder, Config};
-use crate::endpoint::{Endpoint, Endpoints};
+use crate::endpoint::{Endpoint, EndpointAddress, Endpoints};
 use crate::filters::{prelude::*, FilterChain, FilterRegistry, FilterSet};
+use crate::metadata::Value;
 use crate::proxy::{Builder, PendingValidation};
 
 pub struct TestFilterFactory {}
@@ -35,6 +34,10 @@ impl FilterFactory for TestFilterFactory {
         "TestFilter"
     }
 
+    fn config_schema(&self) -> schemars::schema::RootSchema {
+        schemars::schema_for_value!(serde_json::Value::Null)
+    }
+
     fn create_filter(&self, _: CreateFilterArgs) -> Result<FilterInstance, Error> {
         Ok(Self::create_empty_filter())
     }
@@ -57,37 +60,29 @@ impl Filter for TestFilter {
         // append values on each run
         ctx.metadata
             .entry(Arc::new("downstream".into()))
-            .and_modify(|e| e.downcast_mut::<String>().unwrap().push_str(":receive"))
-            .or_insert_with(|| Box::new("receive".to_string()));
+            .and_modify(|e| e.as_mut_string().unwrap().push_str(":receive"))
+            .or_insert_with(|| Value::String("receive".into()));
 
         ctx.contents
-            .append(&mut format!(":odr:{}", ctx.from).into_bytes());
+            .append(&mut format!(":odr:{}", ctx.source).into_bytes());
         Some(ctx.into())
     }
 
     fn write(&self, mut ctx: WriteContext) -> Option<WriteResponse> {
         // append values on each run
         ctx.metadata
-            .entry("upstream".into())
-            .and_modify(|e| e.downcast_mut::<String>().unwrap().push_str(":receive"))
-            .or_insert_with(|| Box::new("receive".to_string()));
+            .entry("upstream".to_string().into())
+            .and_modify(|e| e.as_mut_string().unwrap().push_str(":receive"))
+            .or_insert_with(|| Value::String("receive".to_string()));
 
         ctx.contents
-            .append(&mut format!(":our:{}:{}", ctx.from, ctx.to).into_bytes());
+            .append(&mut format!(":our:{}:{}", ctx.source, ctx.dest).into_bytes());
         Some(ctx.into())
     }
 }
 
-// logger returns a standard out, non structured terminal logger, suitable for using in tests,
-// since it's more human readable.
-pub fn logger() -> Logger {
-    let plain = PlainSyncDecorator::new(std::io::stdout());
-    let drain = FullFormat::new(plain).build().fuse();
-    Logger::root(drain, o!())
-}
-
+#[derive(Default)]
 pub struct TestHelper {
-    pub log: Logger,
     /// Channel to subscribe to, and trigger the shutdown of created resources.
     shutdown_ch: Option<(watch::Sender<()>, watch::Receiver<()>)>,
     server_shutdown_tx: Vec<Option<watch::Sender<()>>>,
@@ -103,19 +98,13 @@ pub struct OpenSocketRecvPacket {
 
 impl Drop for TestHelper {
     fn drop(&mut self) {
-        let log = self.log.clone();
-        for shutdown_tx in self
-            .server_shutdown_tx
-            .iter_mut()
-            .map(|tx| tx.take())
-            .flatten()
-        {
+        for shutdown_tx in self.server_shutdown_tx.iter_mut().flat_map(|tx| tx.take()) {
             shutdown_tx
                 .send(())
-                .map_err(|err| {
-                    warn!(
-                        log,
-                        "Failed to send server shutdown over channel"; "error" => %err
+                .map_err(|error| {
+                    tracing::warn!(
+                        %error,
+                        "Failed to send server shutdown over channel"
                     )
                 })
                 .ok();
@@ -127,16 +116,6 @@ impl Drop for TestHelper {
     }
 }
 
-impl Default for TestHelper {
-    fn default() -> Self {
-        TestHelper {
-            log: logger(),
-            shutdown_ch: None,
-            server_shutdown_tx: vec![],
-        }
-    }
-}
-
 impl TestHelper {
     /// Opens a new socket bound to an ephemeral port
     pub async fn create_socket(&self) -> Arc<UdpSocket> {
@@ -167,7 +146,6 @@ impl TestHelper {
     ) -> (mpsc::Receiver<String>, Arc<UdpSocket>) {
         let (packet_tx, packet_rx) = mpsc::channel::<String>(10);
         let socket = self.create_socket().await;
-        let log = self.log.clone();
         let mut shutdown_rx = self.get_shutdown_subscriber().await;
         let socket_recv = socket.clone();
         tokio::spawn(async move {
@@ -179,8 +157,8 @@ impl TestHelper {
                         let str = from_utf8(&buf[..size]).unwrap().to_string();
                         match packet_tx.send(str).await {
                             Ok(_) => {}
-                            Err(err) => {
-                                warn!(log, "recv_multiple_packets: recv_chan dropped"; "error" => %err);
+                            Err(error) => {
+                                tracing::warn!(target: "recv_multiple_packets", %error, "recv_chan dropped");
                                 return;
                             }
                         };
@@ -196,14 +174,14 @@ impl TestHelper {
 
     /// Runs a simple UDP server that echos back payloads.
     /// Returns the server's address.
-    pub async fn run_echo_server(&mut self) -> SocketAddr {
+    pub async fn run_echo_server(&mut self) -> EndpointAddress {
         self.run_echo_server_with_tap(|_, _, _| {}).await
     }
 
     /// Runs a simple UDP server that echos back payloads.
     /// The provided function is invoked for each received payload.
     /// Returns the server's address.
-    pub async fn run_echo_server_with_tap<F>(&mut self, tap: F) -> SocketAddr
+    pub async fn run_echo_server_with_tap<F>(&mut self, tap: F) -> EndpointAddress
     where
         F: Fn(SocketAddr, &[u8], SocketAddr) + Send + 'static,
     {
@@ -227,7 +205,7 @@ impl TestHelper {
                 }
             }
         });
-        addr
+        addr.into()
     }
 
     /// Run a proxy server with a supplied config.
@@ -271,13 +249,13 @@ pub fn assert_filter_read_no_change<F>(filter: &F)
 where
     F: Filter,
 {
-    let endpoints = vec![Endpoint::new("127.0.0.1:80".parse().unwrap())];
-    let from = "127.0.0.1:90".parse().unwrap();
+    let endpoints = vec!["127.0.0.1:80".parse::<Endpoint>().unwrap()];
+    let source = "127.0.0.1:90".parse().unwrap();
     let contents = "hello".to_string().into_bytes();
 
     match filter.read(ReadContext::new(
         Endpoints::new(endpoints.clone()).unwrap().into(),
-        from,
+        source,
         contents.clone(),
     )) {
         None => unreachable!("should return a result"),
@@ -296,12 +274,12 @@ pub fn assert_write_no_change<F>(filter: &F)
 where
     F: Filter,
 {
-    let endpoint = Endpoint::new("127.0.0.1:90".parse().unwrap());
+    let endpoint = "127.0.0.1:90".parse::<Endpoint>().unwrap();
     let contents = "hello".to_string().into_bytes();
 
     match filter.write(WriteContext::new(
         &endpoint,
-        endpoint.address,
+        endpoint.address.clone(),
         "127.0.0.1:70".parse().unwrap(),
         contents.clone(),
     )) {
@@ -322,7 +300,7 @@ pub fn config_with_dummy_endpoint() -> ConfigBuilder {
 /// Creates a dummy endpoint with `id` as a suffix.
 pub fn ep(id: u8) -> Endpoint {
     Endpoint {
-        address: format!("127.0.0.{}:8080", id).parse().unwrap(),
+        address: ([127, 0, 0, id], 8080).into(),
         ..<_>::default()
     }
 }
@@ -340,11 +318,10 @@ pub fn new_test_chain(registry: &prometheus::Registry) -> Arc<FilterChain> {
     )
 }
 
-pub fn new_registry(log: &slog::Logger) -> FilterRegistry {
-    FilterRegistry::new(FilterSet::default_with(
-        log,
-        std::array::IntoIter::new([DynFilterFactory::from(Box::from(TestFilterFactory {}))]),
-    ))
+pub fn new_registry() -> FilterRegistry {
+    FilterRegistry::new(FilterSet::default_with([DynFilterFactory::from(
+        Box::from(TestFilterFactory {}),
+    )]))
 }
 
 #[cfg(test)]
@@ -359,7 +336,7 @@ mod tests {
         let msg = "hello";
         endpoint
             .socket
-            .send_to(msg.as_bytes(), &echo_addr)
+            .send_to(msg.as_bytes(), &echo_addr.to_socket_addr().unwrap())
             .await
             .unwrap();
         assert_eq!(msg, endpoint.packet_rx.await.unwrap());
