@@ -16,30 +16,26 @@
 
 use std::{
     collections::{HashMap, HashSet},
-    convert::TryFrom,
-    net::SocketAddr,
+    convert::{TryFrom, TryInto},
 };
 
 use bytes::Bytes;
 use prost::Message;
-use slog::{debug, o, warn, Logger};
 use tokio::sync::mpsc;
 
 use crate::{
     cluster::{Cluster as ProxyCluster, ClusterLocalities, Locality, LocalityEndpoints},
-    endpoint::Endpoint,
+    endpoint::{Endpoint, EndpointAddress},
     metadata::MetadataView,
     xds::{
         ads_client::send_discovery_req,
         envoy::{
             config::{
                 cluster::v3::{cluster, Cluster},
-                core::v3::{address, socket_address},
                 endpoint::v3::{lb_endpoint, ClusterLoadAssignment},
             },
             service::discovery::v3::{DiscoveryRequest, DiscoveryResponse},
         },
-        error::Error,
         CLUSTER_TYPE, ENDPOINT_TYPE,
     },
 };
@@ -49,8 +45,6 @@ use crate::{
 /// resources and exposes the results to the caller whenever
 /// the result changes.
 pub(crate) struct ClusterManager {
-    log: Logger,
-
     // Send discovery requests ACKs/NACKs to the server.
     discovery_req_tx: mpsc::Sender<DiscoveryRequest>,
 
@@ -72,12 +66,10 @@ impl ClusterManager {
     /// ACKs/NACKs are sent on the provided channel to be forwarded to the XDS
     /// server.
     pub(in crate::xds) fn new(
-        base: Logger,
         cluster_updates_tx: mpsc::Sender<HashMap<String, ProxyCluster>>,
         discovery_req_tx: mpsc::Sender<DiscoveryRequest>,
     ) -> Self {
         ClusterManager {
-            log: base.new(o!("source" => "xds::ClusterManager")),
             discovery_req_tx,
             cluster_updates_tx,
             clusters: HashMap::new(),
@@ -88,8 +80,7 @@ impl ClusterManager {
     /// Processes a CDS response and updates its cluster view if needed.
     /// This method is called upon receiving a `CDS` `DiscoveryResponse` from the XDS server.
     pub(in crate::xds) async fn on_cluster_response(&mut self, response: DiscoveryResponse) {
-        debug!(
-            self.log,
+        tracing::debug!(
             "{}: received response containing {} resource(s)",
             CLUSTER_TYPE,
             response.resources.len()
@@ -99,7 +90,7 @@ impl ClusterManager {
             .process_cluster_response(response.resources)
             .await
             .err()
-            .map(|err| err.message);
+            .map(|err| err.to_string());
 
         self.send_cluster_discovery_req(response.version_info, response.nonce, error_message)
             .await;
@@ -108,30 +99,30 @@ impl ClusterManager {
     async fn process_cluster_response(
         &mut self,
         resources: Vec<prost_types::Any>,
-    ) -> Result<(), Error> {
+    ) -> crate::Result<()> {
         let mut temp_cluster_set = HashMap::new();
         for resource in resources {
             let cluster = Cluster::decode(Bytes::from(resource.value))
-                .map_err(|err| Error::new(format!("cluster decode error: {}", err.to_string())))?;
+                .map_err(|error| eyre::eyre!(error).wrap_err("cluster decode error"))?;
 
-            // If this cluster doesn't use IP addresses return an error.
-            cluster
-                .cluster_discovery_type
-                .map(|discovery_type| match discovery_type {
-                    // See envoy::config::cluster::v3::cluster::DiscoveryType for corresponding values.
-                    cluster::ClusterDiscoveryType::Type(discovery_type) if discovery_type == 0 => {
-                        Ok(())
-                    }
-                    cluster::ClusterDiscoveryType::Type(discovery_type) => Err(format!(
+            match cluster.cluster_discovery_type {
+                // See envoy::config::cluster::v3::cluster::DiscoveryType for corresponding values.
+                Some(cluster::ClusterDiscoveryType::Type(typ)) if typ == 0 => {}
+                Some(cluster::ClusterDiscoveryType::Type(typ)) => {
+                    return Err(eyre::eyre!(
                         "unsupported cluster type '{}': Only STATIC is supported",
-                        discovery_type
-                    )),
-                    cluster::ClusterDiscoveryType::ClusterType(_) => {
-                        Err("Custom cluster types are not supported".into())
-                    }
-                })
-                .unwrap_or_else(|| Err("no cluster_discovery_type was provided in request".into()))
-                .map_err(Error::new)?;
+                        typ
+                    ))
+                }
+                Some(cluster::ClusterDiscoveryType::ClusterType(_)) => {
+                    return Err(eyre::eyre!("custom cluster types are unsupported."))
+                }
+                None => {
+                    return Err(eyre::eyre!(
+                        "no cluster_discovery_type was provided in request"
+                    ))
+                }
+            }
 
             let localities = cluster
                 .load_assignment
@@ -173,8 +164,7 @@ impl ClusterManager {
         &mut self,
         response: DiscoveryResponse,
     ) {
-        debug!(
-            self.log,
+        tracing::debug!(
             "{}: received response containing {} resource(s)",
             ENDPOINT_TYPE,
             response.resources.len()
@@ -187,7 +177,7 @@ impl ClusterManager {
             .process_cluster_load_assignment_response(response.resources)
             .await
             .err()
-            .map(|err| err.message);
+            .map(|err| err.to_string());
 
         self.send_cluster_load_assignment_discovery_req(
             response.version_info,
@@ -200,14 +190,11 @@ impl ClusterManager {
     async fn process_cluster_load_assignment_response(
         &mut self,
         resources: Vec<prost_types::Any>,
-    ) -> Result<(), Error> {
+    ) -> crate::Result<()> {
         for resource in resources {
             let assignment =
-                ClusterLoadAssignment::decode(Bytes::from(resource.value)).map_err(|err| {
-                    Error::new(format!(
-                        "cluster load assignment decode error: {}",
-                        err.to_string()
-                    ))
+                ClusterLoadAssignment::decode(Bytes::from(resource.value)).map_err(|error| {
+                    eyre::eyre!(error).wrap_err("cluster load assignment decode error")
                 })?;
 
             match self.clusters.get_mut(&assignment.cluster_name) {
@@ -219,9 +206,9 @@ impl ClusterManager {
                 None => {
                     // Got an endpoint that we don't have a cluster for. This likely means that
                     // the cluster has been deleted since ADS handles resource ordering.
-                    warn!(
-                        self.log,
-                        "Got endpoint for non-existing cluster"; "name" => assignment.cluster_name
+                    tracing::warn!(
+                        name = %assignment.cluster_name,
+                        "Got endpoint for non-existing cluster",
                     );
                 }
             }
@@ -239,7 +226,7 @@ impl ClusterManager {
             .send(self.clusters.clone())
             .await
             .map_err(|err| {
-                warn!(self.log, "Failed to send cluster updates downstream");
+                tracing::warn!("Failed to send cluster updates downstream");
                 err
             })
             // ok is safe here because an error can only be due to downstream dropping
@@ -252,7 +239,7 @@ impl ClusterManager {
     /// components that we're interested in.
     fn process_cluster_load_assignment(
         mut assignment: ClusterLoadAssignment,
-    ) -> Result<ClusterLocalities, Error> {
+    ) -> crate::Result<ClusterLocalities> {
         let mut existing_endpoints = HashMap::new();
 
         for lb_locality in assignment.endpoints {
@@ -280,55 +267,26 @@ impl ClusterManager {
                     lb_endpoint::HostIdentifier::EndpointName(name_reference) => {
                         match assignment.named_endpoints.remove(&name_reference) {
                             Some(endpoint) => Ok(endpoint),
-                            None => Err(Error::new(format!(
+                            None => Err(eyre::eyre!(
                                 "no endpoint found name reference {}",
                                 name_reference
-                            ))),
+                            )),
                         }
                     }
                 }?;
 
                 // Extract the endpoint's address.
-                let address = endpoint
+                let address: EndpointAddress = endpoint
                     .address
                     .and_then(|address| address.address)
-                    .map(|address| match address {
-                        address::Address::SocketAddress(sock_addr) => {
-                            // We only support IP addresses so anything else is an error.
-                            let address =
-                                sock_addr
-                                    .address
-                                    .parse::<std::net::IpAddr>()
-                                    .map_err(|err| {
-                                        Error::new(format!("invalid ip address: {}", err))
-                                    })?;
-                            sock_addr
-                                .port_specifier
-                                .map(|port_specifier| match port_specifier {
-                                    socket_address::PortSpecifier::PortValue(port) => {
-                                        Ok((address, port as u16))
-                                    }
-                                    socket_address::PortSpecifier::NamedPort(_) => Err(Error::new(
-                                        "named_port on socket addresses is not supported",
-                                    )),
-                                })
-                                .unwrap_or_else(|| {
-                                    Err(Error::new("no port specifier was provided"))
-                                })
-                        }
-                        invalid => Err(Error::new(format!(
-                            "unsupported endpoint address type: {:?}",
-                            invalid
-                        ))),
-                    })
-                    .unwrap_or_else(|| Err(Error::new("received `Endpoint` with no `address`")))?;
+                    .ok_or_else(|| eyre::eyre!("No address provided."))?
+                    .try_into()?;
 
                 endpoints.push(Endpoint::with_metadata(
-                    SocketAddr::from(address),
+                    address,
                     metadata
                         .map(MetadataView::try_from)
-                        .transpose()
-                        .map_err(Error::new)?
+                        .transpose()?
                         .unwrap_or_default(),
                 ));
             }
@@ -339,13 +297,6 @@ impl ClusterManager {
         Ok(existing_endpoints)
     }
 
-    // Notify that we are about to reconnect the GRPC stream.
-    pub(in crate::xds) fn on_reconnect(&mut self) {
-        // Reset any last seen version and nonce since we'll be working
-        // with a new connection from now on with a clean slate.
-        self.last_seen_cluster_load_assignment_version = None
-    }
-
     // Send a CDS ACK/NACK request to the server.
     async fn send_cluster_discovery_req(
         &mut self,
@@ -390,7 +341,6 @@ impl ClusterManager {
         resource_names: Vec<String>,
     ) {
         send_discovery_req(
-            self.log.clone(),
             type_url,
             version_info,
             response_nonce,
@@ -405,8 +355,7 @@ impl ClusterManager {
 #[cfg(test)]
 mod tests {
     use super::{ClusterManager, ProxyCluster};
-    use crate::endpoint::Endpoint as ProxyEndpoint;
-    use crate::test_utils::logger;
+    use crate::endpoint::{Endpoint as ProxyEndpoint, EndpointAddress};
     use crate::xds::envoy::config::cluster::v3::{cluster::ClusterDiscoveryType, Cluster};
     use crate::xds::envoy::config::core::v3::{
         address, socket_address::PortSpecifier, Address, Metadata, SocketAddress,
@@ -422,7 +371,6 @@ mod tests {
     use prost_types::Struct as ProstStruct;
     use prost_types::Value as ProstValue;
     use std::collections::{HashMap, HashSet};
-    use std::net::SocketAddr;
     use tokio::sync::mpsc;
 
     type ClusterState = HashMap<String, ProxyCluster>;
@@ -434,7 +382,7 @@ mod tests {
 
         let (cluster_updates_tx, _) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         let initial_names = vec!["a".into()];
         cm.on_cluster_response(cluster_discovery_response("1", "2", initial_names.clone()))
@@ -476,7 +424,7 @@ mod tests {
 
         let (cluster_updates_tx, _) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         let names = vec!["a".into(), "b".into()];
         cm.on_cluster_response(cluster_discovery_response("3", "6", names.clone()))
@@ -484,17 +432,15 @@ mod tests {
 
         let _ = recv_cluster_and_endpoint_reqs(&mut discovery_req_rx).await;
 
-        let mut version = 4;
-        let mut nonce = 9;
+        let mut version = 4u8;
+        let mut nonce = 9u8;
         for _ in 0..3 {
             let v = &version.to_string();
             let n = &nonce.to_string();
 
-            let new_address = format!("127.0.0.{}", nonce);
-            let new_port = 2020 + nonce;
-            let expected_socket_addr = format!("{}:{}", new_address, new_port)
-                .parse::<SocketAddr>()
-                .unwrap();
+            let new_address = std::net::Ipv4Addr::from([127, 0, 0, nonce]);
+            let new_port = 2020 + nonce as u16;
+            let expected_socket_addr = (new_address, new_port);
             cm.on_cluster_load_assignment_response(endpoint_discovery_response_with_update(
                 v,
                 n,
@@ -506,10 +452,12 @@ mod tests {
                                 address: Some(Address {
                                     address: Some(address::Address::SocketAddress(SocketAddress {
                                         protocol: 1,
-                                        address: new_address.clone(),
+                                        address: new_address.to_string(),
                                         resolver_name: "".into(),
                                         ipv4_compat: true,
-                                        port_specifier: Some(PortSpecifier::PortValue(new_port)),
+                                        port_specifier: Some(PortSpecifier::PortValue(
+                                            new_port as u32,
+                                        )),
                                     })),
                                 }),
                                 health_check_config: None,
@@ -539,7 +487,7 @@ mod tests {
                     .get(&None)
                     .unwrap()
                     .endpoints,
-                vec![ProxyEndpoint::new(expected_socket_addr)]
+                vec![ProxyEndpoint::new(expected_socket_addr.into())]
             );
             assert_eq!(
                 cm.clusters
@@ -560,7 +508,7 @@ mod tests {
 
         let (cluster_updates_tx, _) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         let names = vec!["a".into(), "b".into()];
         cm.on_cluster_response(cluster_discovery_response("3", "6", names.clone()))
@@ -596,7 +544,7 @@ mod tests {
 
         let (cluster_updates_tx, _) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         let initial_names = vec!["a".into()];
         cm.on_cluster_response(cluster_discovery_response("1", "2", initial_names.clone()))
@@ -627,7 +575,7 @@ mod tests {
 
         let (cluster_updates_tx, _) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         cm.on_cluster_response(cluster_discovery_response(
             "1",
@@ -677,7 +625,7 @@ mod tests {
 
         let (cluster_updates_tx, mut cluster_updates_rx) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, _) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         cm.on_cluster_response(cluster_discovery_response(
             "1",
@@ -692,8 +640,8 @@ mod tests {
         let cluster_a = cluster_state.get("a").unwrap();
         let cluster_b = cluster_state.get("b").unwrap();
 
-        assert_cluster_has_lone_static_address(cluster_a, "127.0.0.1:2020");
-        assert_cluster_has_lone_static_address(cluster_b, "127.0.0.1:2020");
+        assert_cluster_has_lone_static_address(cluster_a, &([127, 0, 0, 1], 2020).into());
+        assert_cluster_has_lone_static_address(cluster_b, &([127, 0, 0, 1], 2020).into());
 
         // Update one of the clusters and check that the new cluster set is sent downstream.
         cm.on_cluster_response(cluster_discovery_response_with_update(
@@ -730,8 +678,8 @@ mod tests {
         let cluster_a = cluster_state.get("a").unwrap();
         let cluster_b = cluster_state.get("b").unwrap();
 
-        assert_cluster_has_lone_static_address(cluster_a, "127.0.0.10:3030");
-        assert_cluster_has_lone_static_address(cluster_b, "127.0.0.1:2020");
+        assert_cluster_has_lone_static_address(cluster_a, &([127, 0, 0, 10], 3030).into());
+        assert_cluster_has_lone_static_address(cluster_b, &([127, 0, 0, 1], 2020).into());
     }
 
     #[tokio::test]
@@ -740,7 +688,7 @@ mod tests {
 
         let (cluster_updates_tx, mut cluster_updates_rx) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, _) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         cm.on_cluster_response(cluster_discovery_response(
             "1",
@@ -786,8 +734,8 @@ mod tests {
         let cluster_a = cluster_state.get("a").unwrap();
         let cluster_b = cluster_state.get("b").unwrap();
 
-        assert_cluster_has_lone_static_address(cluster_a, "127.0.0.1:2020");
-        assert_cluster_has_lone_static_address(cluster_b, "127.0.0.9:4040");
+        assert_cluster_has_lone_static_address(cluster_a, &([127, 0, 0, 1], 2020).into());
+        assert_cluster_has_lone_static_address(cluster_b, &([127, 0, 0, 9], 4040).into());
     }
 
     #[tokio::test]
@@ -796,7 +744,7 @@ mod tests {
 
         let (cluster_updates_tx, mut cluster_updates_rx) = mpsc::channel::<ClusterState>(100);
         let (discovery_req_tx, _) = mpsc::channel::<DiscoveryRequest>(100);
-        let mut cm = ClusterManager::new(logger(), cluster_updates_tx, discovery_req_tx);
+        let mut cm = ClusterManager::new(cluster_updates_tx, discovery_req_tx);
 
         cm.on_cluster_response(cluster_discovery_response_with_update(
             "1",
@@ -845,12 +793,13 @@ mod tests {
         assert_eq!(dyn_metadata.len(), 1);
 
         let value = dyn_metadata
-            .get(&format!("key-{}", cluster_name).into())
+            .get(&format!("key-{cluster_name}").into())
             .unwrap();
         assert_eq!(
             value,
             &serde_yaml::Value::from(
-                std::array::IntoIter::new([("one".into(), "two".into())])
+                [("one".into(), "two".into())]
+                    .into_iter()
                     .collect::<serde_yaml::Mapping>()
             )
         );
@@ -1054,10 +1003,13 @@ mod tests {
         assert_eq!(nonce, &req.response_nonce);
     }
 
-    fn assert_cluster_has_lone_static_address(cluster: &ProxyCluster, expected_addr: &str) {
+    fn assert_cluster_has_lone_static_address(
+        cluster: &ProxyCluster,
+        expected_addr: &EndpointAddress,
+    ) {
         assert_eq!(
-            cluster.localities.get(&None).unwrap().endpoints[0].address,
-            expected_addr.parse().unwrap()
+            &cluster.localities.get(&None).unwrap().endpoints[0].address,
+            expected_addr,
         )
     }
 }
