@@ -21,7 +21,6 @@ use crate::xds::envoy::config::listener::v3::{
     filter::ConfigType as LdsConfigType, FilterChain, Listener,
 };
 use crate::xds::envoy::service::discovery::v3::{DiscoveryRequest, DiscoveryResponse};
-use crate::xds::error::Error;
 use crate::xds::LISTENER_TYPE;
 
 use std::sync::Arc;
@@ -30,15 +29,12 @@ use crate::xds::ads_client::send_discovery_req;
 use bytes::Bytes;
 use prometheus::Registry;
 use prost::Message;
-use slog::{debug, warn, Logger};
 use tokio::sync::mpsc;
 
 /// Tracks FilterChain resources on the LDS DiscoveryResponses and
 /// instantiates a corresponding proxy filter chain and exposes it
 /// to the caller whenever the filter chain changes.
 pub(crate) struct ListenerManager {
-    log: Logger,
-
     metrics_registry: Registry,
 
     // Registry to lookup filter factories by name.
@@ -53,12 +49,10 @@ pub(crate) struct ListenerManager {
 
 impl ListenerManager {
     pub(in crate::xds) fn new(
-        log: Logger,
         args: ListenerManagerArgs,
         discovery_req_tx: mpsc::Sender<DiscoveryRequest>,
     ) -> Self {
         ListenerManager {
-            log,
             metrics_registry: args.metrics_registry,
             filter_registry: args.filter_registry,
             discovery_req_tx,
@@ -67,8 +61,7 @@ impl ListenerManager {
     }
 
     pub(in crate::xds) async fn on_listener_response(&mut self, response: DiscoveryResponse) {
-        debug!(
-            self.log,
+        tracing::debug!(
             "{}: received response containing {} resource(s)",
             LISTENER_TYPE,
             response.resources.len()
@@ -77,7 +70,7 @@ impl ListenerManager {
         let result = self
             .process_listener_response(response.resources)
             .await
-            .map_err(|err| err.message);
+            .map_err(|err| err.to_string());
 
         let error_message = match result {
             Ok(filter_chain) => {
@@ -85,7 +78,7 @@ impl ListenerManager {
                     .send(Arc::new(filter_chain))
                     .await
                     .map_err(|err| {
-                        warn!(self.log, "Failed to send filter chain update on channel");
+                        tracing::warn!("Failed to send filter chain update on channel");
                         err
                     })
                     // ok is safe here because an error can only be due to the consumer dropping
@@ -111,29 +104,29 @@ impl ListenerManager {
     async fn process_listener_response(
         &mut self,
         mut resources: Vec<prost_types::Any>,
-    ) -> Result<ProxyFilterChain, Error> {
+    ) -> crate::Result<ProxyFilterChain> {
         let resource = match resources.len() {
             0 => return Ok(ProxyFilterChain::new(vec![], &self.metrics_registry)?),
             1 => resources.swap_remove(0),
             n => {
-                return Err(Error::new(format!(
+                return Err(eyre::eyre!(
                     "at most 1 listener can be specified: got {}",
                     n
-                )))
+                ))
             }
         };
 
         let mut listener = Listener::decode(Bytes::from(resource.value))
-            .map_err(|err| Error::new(format!("listener decode error: {}", err.to_string())))?;
+            .map_err(|err| eyre::eyre!("listener decode error: {}", err.to_string()))?;
 
         let lds_filter_chain = match listener.filter_chains.len() {
             0 => return Ok(ProxyFilterChain::new(vec![], &self.metrics_registry)?),
             1 => listener.filter_chains.swap_remove(0),
             n => {
-                return Err(Error::new(format!(
+                return Err(eyre::eyre!(
                     "at most 1 filter chain can be provided: got {}",
                     n
-                )))
+                ))
             }
         };
 
@@ -143,28 +136,25 @@ impl ListenerManager {
     fn process_filter_chain(
         &self,
         lds_filter_chain: FilterChain,
-    ) -> Result<ProxyFilterChain, Error> {
+    ) -> crate::Result<ProxyFilterChain> {
         let mut filters = vec![];
         for filter in lds_filter_chain.filters {
             let config = filter
                 .config_type
                 .map(|config| match config {
                     LdsConfigType::TypedConfig(config) => Ok(config),
-                    invalid => Err(Error::new(format!(
-                        "unsupported filter.config_type: {:?}",
-                        invalid
-                    ))),
+                    invalid => Err(eyre::eyre!("unsupported filter.config_type: {:?}", invalid)),
                 })
                 .transpose()?;
-            let create_filter_args =
-                CreateFilterArgs::dynamic(self.metrics_registry.clone(), config);
+
+            let create_filter_args = CreateFilterArgs::dynamic(
+                self.filter_registry.clone(),
+                self.metrics_registry.clone(),
+                config,
+            );
 
             let name = filter.name;
-            let filter = self
-                .filter_registry
-                .get(&name, create_filter_args)
-                .map_err(|err| Error::new(format!("{}", err)))?;
-
+            let filter = self.filter_registry.get(&name, create_filter_args)?;
             filters.push((name, filter));
         }
 
@@ -181,7 +171,6 @@ impl ListenerManager {
         resource_names: Vec<String>,
     ) {
         send_discovery_req(
-            self.log.clone(),
             type_url,
             version_info,
             response_nonce,
@@ -197,7 +186,6 @@ impl ListenerManager {
 mod tests {
     use super::ListenerManager;
     use crate::filters::{manager::ListenerManagerArgs, prelude::*};
-    use crate::test_utils::logger;
     use crate::xds::envoy::config::listener::v3::{
         filter::ConfigType, Filter as LdsFilter, FilterChain as LdsFilterChain, Listener,
     };
@@ -218,7 +206,7 @@ mod tests {
     // A simple filter that will be used in the following tests.
     // It appends a string to each payload.
     const APPEND_TYPE_URL: &str = "filter.append";
-    #[derive(Clone, PartialEq, Serialize, Deserialize)]
+    #[derive(Clone, PartialEq, Serialize, Deserialize, schemars::JsonSchema)]
     pub struct Append {
         pub value: Option<prost::alloc::string::String>,
     }
@@ -247,9 +235,9 @@ mod tests {
     }
 
     fn new_registry() -> FilterRegistry {
-        FilterRegistry::new(FilterSet::with(std::array::IntoIter::new([
-            DynFilterFactory::from(Box::from(AppendFactory)),
-        ])))
+        FilterRegistry::new(FilterSet::with([DynFilterFactory::from(Box::from(
+            AppendFactory,
+        ))]))
     }
 
     struct AppendFactory;
@@ -259,6 +247,10 @@ mod tests {
             APPEND_TYPE_URL
         }
 
+        fn config_schema(&self) -> schemars::schema::RootSchema {
+            schemars::schema_for!(Append)
+        }
+
         fn create_filter(&self, args: CreateFilterArgs) -> Result<FilterInstance, Error> {
             let (config_json, filter) = args
                 .config
@@ -289,7 +281,6 @@ mod tests {
         let (filter_chain_updates_tx, mut filter_chain_updates_rx) = mpsc::channel(10);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel(10);
         let mut manager = ListenerManager::new(
-            logger(),
             ListenerManagerArgs::new(
                 Registry::default(),
                 filter_registry,
@@ -394,7 +385,6 @@ mod tests {
         let (filter_chain_updates_tx, mut filter_chain_updates_rx) = mpsc::channel(10);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel(10);
         let mut manager = ListenerManager::new(
-            logger(),
             ListenerManagerArgs::new(
                 Registry::default(),
                 filter_registry,
@@ -428,7 +418,7 @@ mod tests {
         for (i, (filter, expected_payload)) in test_cases.into_iter().enumerate() {
             // Send a response with a filter chain.
             let lds_listener = create_lds_listener(
-                format!("test-listener-{}", i),
+                format!("test-listener-{i}"),
                 vec![create_lds_filter_chain(filter)],
             );
             let mut buf = vec![];
@@ -438,7 +428,7 @@ mod tests {
                 value: buf,
             };
 
-            let (version_info, nonce) = (format!("version-{}", i), format!("nonce-{}", i));
+            let (version_info, nonce) = (format!("version-{i}"), format!("nonce-{i}"));
             // Send the proto message as a DiscoveryResponse to the manager.
             manager
                 .on_listener_response(DiscoveryResponse {
@@ -503,7 +493,6 @@ mod tests {
         let (filter_chain_updates_tx, _filter_chain_updates_rx) = mpsc::channel(10);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel(10);
         let mut manager = ListenerManager::new(
-            logger(),
             ListenerManagerArgs::new(
                 Registry::default(),
                 filter_registry,
@@ -611,10 +600,9 @@ mod tests {
         let (filter_chain_updates_tx, _filter_chain_updates_rx) = mpsc::channel(10);
         let (discovery_req_tx, mut discovery_req_rx) = mpsc::channel(10);
         let mut manager = ListenerManager::new(
-            logger(),
             ListenerManagerArgs::new(
                 Registry::default(),
-                FilterRegistry::new(FilterSet::default(&logger())),
+                FilterRegistry::new(FilterSet::default()),
                 filter_chain_updates_tx,
             ),
             discovery_req_tx,
