@@ -14,21 +14,19 @@
  *  limitations under the License.
  */
 
-use std::net::SocketAddr;
+use std::net::{Ipv4Addr, SocketAddr};
 
-use slog::info;
 use tokio::time::{timeout, Duration};
 
 use quilkin::{
     config::{Builder, Filter},
     endpoint::Endpoint,
     filters::compress,
-    test_utils::{logger, TestHelper},
+    test_utils::TestHelper,
 };
 
 #[tokio::test]
 async fn client_and_server() {
-    let log = logger();
     let mut t = TestHelper::default();
     let echo = t.run_echo_server().await;
 
@@ -42,7 +40,7 @@ on_write: COMPRESS
         .with_port(server_port)
         .with_static(
             vec![Filter {
-                name: compress::factory(&log).name().into(),
+                name: compress::factory().name().into(),
                 config: serde_yaml::from_str(yaml).unwrap(),
             }],
             vec![Endpoint::new(echo)],
@@ -61,12 +59,10 @@ on_write: DECOMPRESS
         .with_port(client_port)
         .with_static(
             vec![Filter {
-                name: compress::factory(&log).name().into(),
+                name: compress::factory().name().into(),
                 config: serde_yaml::from_str(yaml).unwrap(),
             }],
-            vec![Endpoint::new(
-                format!("127.0.0.1:{}", server_port).parse().unwrap(),
-            )],
+            vec![Endpoint::new((Ipv4Addr::LOCALHOST, server_port).into())],
         )
         .build();
     // Run client proxy.
@@ -76,8 +72,8 @@ on_write: DECOMPRESS
     let (mut rx, tx) = t.open_socket_and_recv_multiple_packets().await;
 
     // game_client
-    let local_addr: SocketAddr = format!("127.0.0.1:{}", client_port).parse().unwrap();
-    info!(t.log, "Sending hello"; "address" => local_addr);
+    let local_addr = SocketAddr::from((Ipv4Addr::LOCALHOST, client_port));
+    tracing::info!(address = %local_addr, "Sending hello");
     tx.send_to(b"hello", &local_addr).await.unwrap();
 
     let expected = timeout(Duration::from_secs(5), rx.recv())
