@@ -20,7 +20,6 @@ use std::{
 };
 
 use serde_yaml::{Mapping, Value};
-use slog::info;
 
 use quilkin::{
     config::{Builder as ConfigBuilder, Filter},
@@ -51,7 +50,7 @@ async fn test_filter() {
         .build();
 
     // Run server proxy.
-    let registry = new_registry(&t.log);
+    let registry = new_registry();
     t.run_server_with_builder(
         ProxyBuilder::from(Arc::new(server_config))
             .with_filter_registry(registry)
@@ -67,15 +66,14 @@ async fn test_filter() {
                 name: "TestFilter".to_string(),
                 config: None,
             }],
-            vec![Endpoint::new(SocketAddr::new(
-                IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)),
-                server_port,
-            ))],
+            vec![Endpoint::new(
+                SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), server_port).into(),
+            )],
         )
         .build();
 
     // Run client proxy.
-    let registry = new_registry(&t.log);
+    let registry = new_registry();
     t.run_server_with_builder(
         ProxyBuilder::from(Arc::new(client_config))
             .with_filter_registry(registry)
@@ -87,7 +85,7 @@ async fn test_filter() {
 
     // game_client
     let local_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), client_port);
-    info!(t.log, "Sending hello"; "address" => local_addr);
+    tracing::info!(address = %local_addr, "Sending hello");
     socket.send_to(b"hello", &local_addr).await.unwrap();
 
     let result = recv_chan.recv().await.unwrap();
@@ -113,7 +111,7 @@ async fn debug_filter() {
     let mut t = TestHelper::default();
 
     // handy for grabbing the configuration name
-    let factory = debug::factory(&t.log);
+    let factory = debug::factory();
 
     // create an echo server as an endpoint.
     let echo = t.run_echo_server().await;
@@ -146,10 +144,9 @@ async fn debug_filter() {
                 name: factory.name().into(),
                 config: Some(serde_yaml::Value::Mapping(map)),
             }],
-            vec![Endpoint::new(SocketAddr::new(
-                IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)),
-                server_port,
-            ))],
+            vec![Endpoint::new(
+                SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), server_port).into(),
+            )],
         )
         .build();
     t.run_server_with_config(client_config);
@@ -159,7 +156,7 @@ async fn debug_filter() {
 
     // game client
     let local_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), client_port);
-    info!(t.log, "Sending hello"; "address" => local_addr);
+    tracing::info!(address = %local_addr, "Sending hello");
     socket.send_to(b"hello", &local_addr).await.unwrap();
 
     // since the debug filter doesn't change the data, it should be exactly the same
