@@ -21,22 +21,22 @@ use tokio::time::{timeout, Duration};
 use quilkin::{
     config::{Builder, Filter},
     endpoint::Endpoint,
-    filters::{capture_bytes, token_router},
+    filters::{capture, token_router},
     metadata::MetadataView,
-    test_utils::{logger, TestHelper},
+    test_utils::TestHelper,
 };
 
-/// This test covers both token_router and capture_bytes filters,
+/// This test covers both token_router and capture filters,
 /// since they work in concert together.
 #[tokio::test]
 async fn token_router() {
-    let log = logger();
     let mut t = TestHelper::default();
     let echo = t.run_echo_server().await;
 
     let capture_yaml = "
-size: 3
-remove: true
+suffix:
+    size: 3
+    remove: true
 ";
     let endpoint_metadata = "
 quilkin.dev:
@@ -49,11 +49,11 @@ quilkin.dev:
         .with_static(
             vec![
                 Filter {
-                    name: capture_bytes::factory(&log).name().into(),
+                    name: capture::factory().name().into(),
                     config: serde_yaml::from_str(capture_yaml).unwrap(),
                 },
                 Filter {
-                    name: token_router::factory(&log).name().into(),
+                    name: token_router::factory().name().into(),
                     config: None,
                 },
             ],
