@@ -14,9 +14,7 @@
  * limitations under the License.
  */
 
-#[allow(warnings)]
 quilkin::include_proto!("xds.core.v3");
-#[allow(warnings)]
 quilkin::include_proto!("google.rpc");
 
 #[allow(warnings)]
@@ -110,7 +108,7 @@ mod quilkin_proto {
             pub mod concatenate_bytes {
                 pub mod v1alpha1 {
                     #![doc(hidden)]
-                    tonic::include_proto!("quilkin.extensions.filters.concatenate_bytes.v1alpha1");
+                    tonic::include_proto!("quilkin.filters.concatenate_bytes.v1alpha1");
                 }
             }
         }
@@ -131,17 +129,14 @@ use envoy::service::discovery::v3::aggregated_discovery_service_server::{
 use envoy::service::discovery::v3::{
     DeltaDiscoveryRequest, DeltaDiscoveryResponse, DiscoveryRequest, DiscoveryResponse,
 };
-use quilkin_proto::extensions::filters::concatenate_bytes::v1alpha1::concatenate_bytes::{
-    Strategy, StrategyValue,
+use quilkin_proto::extensions::filters::concatenate_bytes::v1alpha1::{
+    concatenate_bytes::{Strategy, StrategyValue},
+    ConcatenateBytes,
 };
-use quilkin_proto::extensions::filters::concatenate_bytes::v1alpha1::ConcatenateBytes;
 
-use quilkin::config::Config;
-use quilkin::test_utils::{logger, TestHelper};
-use quilkin::Builder;
+use quilkin::{config::Config, endpoint::EndpointAddress, test_utils::TestHelper, Builder};
 
 use prost::Message;
-use slog::{info, o, Logger};
 use std::collections::HashMap;
 use std::net::SocketAddr;
 use std::sync::Arc;
@@ -158,7 +153,6 @@ const LISTENER_TYPE: &str = "type.googleapis.com/envoy.config.listener.v3.Listen
 // forwards DiscoveryResponse(s) to the client. A rx chan is passed in upon creation
 // and can be used by the test to drive the DiscoveryResponses sent by the server to the client.
 struct ControlPlane {
-    log: Logger,
     source_discovery_response_rx:
         tokio::sync::Mutex<Option<mpsc::Receiver<Result<DiscoveryResponse, tonic::Status>>>>,
     shutdown_rx: watch::Receiver<()>,
@@ -182,7 +176,6 @@ impl ADS for ControlPlane {
             .take()
             .unwrap();
 
-        let log = self.log.clone();
         let mut shutdown_rx = self.shutdown_rx.clone();
         let (discovery_response_tx, discovery_response_rx) = mpsc::channel(1);
         tokio::spawn(async move {
@@ -194,7 +187,7 @@ impl ADS for ControlPlane {
                     source_response = source_discovery_response_rx.recv() => {
                         match source_response {
                             None => {
-                                info!(log, "Stopping updates to client: source was dropped");
+                                tracing::info!("Stopping updates to client: source was dropped");
                                 return;
                             },
                             Some(result) => {
@@ -233,21 +226,15 @@ dynamic:
     ";
 
     let config: Arc<Config> = Arc::new(serde_yaml::from_str(config).unwrap());
-    let server = Builder::from(config)
-        .with_log(logger())
-        .validate()
-        .unwrap()
-        .build();
+    let server = Builder::from(config).validate().unwrap().build();
 
     let (_shutdown_tx, shutdown_rx) = tokio::sync::watch::channel(());
     let (discovery_response_tx, discovery_response_rx) = mpsc::channel(1);
 
     let mut control_plane_shutdown_rx = shutdown_rx.clone();
-    let log = t.log.new(o!("source" => "control-plane"));
     tokio::spawn(async move {
         let server = ADSServer::new(ControlPlane {
             source_discovery_response_rx: tokio::sync::Mutex::new(Some(discovery_response_rx)),
-            log,
             shutdown_rx: control_plane_shutdown_rx.clone(),
         });
         let server = Server::builder().add_service(server);
@@ -295,7 +282,7 @@ dynamic:
         // Open a socket we can use to talk to the proxy and receive response back on.
         let (mut response_rx, socket) = t.open_socket_and_recv_multiple_packets().await;
 
-        let expected_response = format!("a{}{}", b1, b2);
+        let expected_response = format!("a{b1}{b2}");
         let mut interval = time::interval(Duration::from_millis(10));
         loop {
             // Send a packet, it should be suffixed with the new filter configs.
@@ -331,7 +318,7 @@ fn concat_listener_discovery_response(
     nonce: &str,
     bytes: Vec<Vec<u8>>,
 ) -> DiscoveryResponse {
-    let filter_name = "quilkin.extensions.filters.concatenate_bytes.v1alpha1.ConcatenateBytes";
+    let filter_name = "quilkin.filters.concatenate_bytes.v1alpha1.ConcatenateBytes";
     let filters = bytes
         .into_iter()
         .map(|value| LdsFilter {
@@ -380,7 +367,7 @@ fn cluster_discovery_response(
     name: String,
     version_info: &str,
     nonce: &str,
-    endpoint_addr: SocketAddr,
+    endpoint_addr: EndpointAddress,
 ) -> DiscoveryResponse {
     let cluster = create_cluster_resource(&name, endpoint_addr);
     let mut value = vec![];
@@ -401,7 +388,7 @@ fn cluster_discovery_response(
 }
 
 #[allow(deprecated)]
-fn create_cluster_resource(name: &str, endpoint_addr: SocketAddr) -> Cluster {
+fn create_cluster_resource(name: &str, endpoint_addr: EndpointAddress) -> Cluster {
     Cluster {
         name: name.into(),
         transport_socket_matches: vec![],
@@ -449,7 +436,9 @@ fn create_cluster_resource(name: &str, endpoint_addr: SocketAddr) -> Cluster {
     }
 }
 
-fn create_endpoint_resource(cluster_name: &str, address: SocketAddr) -> ClusterLoadAssignment {
+fn create_endpoint_resource(cluster_name: &str, address: EndpointAddress) -> ClusterLoadAssignment {
+    let address = address.to_socket_addr().unwrap();
+
     ClusterLoadAssignment {
         cluster_name: cluster_name.into(),
         endpoints: vec![LocalityLbEndpoints {
